<?php
/**
 * WPS_Siren functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * WPS_Siren
 */

if ( ! function_exists( 'wpsmart_siren_setup' ) ) :

	function wpsmart_siren_setup() {

		load_theme_textdomain( 'siren', get_template_directory() . '/languages' );

		add_theme_support( 'automatic-feed-links' );

		add_theme_support( 'title-tag' );

        add_theme_support( 'post-thumbnails' );
        add_image_size( 'siren-main-post-thumb', 500, 500, true );
        add_image_size( 'siren-medium-post-thumb', 350, 400, true );
        add_image_size( 'siren-small-post-thumb', 200, 150, true );
        add_image_size( 'siren-extra-small-post-thumb', 180, 100, true );
        add_image_size( 'siren-extra-full-page-thumb', 1200, 1200, true );

		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( '_s_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );

		// Adding support for core block visual styles.
		add_theme_support( 'wp-block-styles' );

		// Add support for full and wide align images.
		add_theme_support( 'align-wide' );


		// Add support for responsive embeds.
		add_theme_support( 'responsive-embeds' );
	}
endif;
add_action( 'after_setup_theme', 'wpsmart_siren_setup' );

function wpsmart_siren_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'wpsmart_siren_content_width', 640 );
}
add_action( 'after_setup_theme', 'wpsmart_siren_content_width', 0 );

/**
 * Register Google Fonts
 */
function wpsmart_siren_fonts_url() {
    $fonts_url = '';
    $fonts     = array();
    $subsets   = 'latin,latin-ext';

    /*
     * Translators: If there are characters in your language that are not supported
     * by Oswald, translate this to 'off'. Do not translate into your own language.
     */
    if ( 'off' !== _x( 'on', 'Roboto font: on or off', 'siren' ) ) {
        $fonts[] = 'Roboto:400,500,700';
    }

    /*
     * Translators: If there are characters in your language that are not supported
     * by Montserrat, translate this to 'off'. Do not translate into your own language.
     */
    if ( 'off' !== _x( 'on', 'Poppins font: on or off', 'siren' ) ) {
        $fonts[] = 'Poppins:400,500';
    }


    if ( $fonts ) {
        $fonts_url = add_query_arg( array(
            'family' => urlencode( implode( '|', $fonts ) ),
            'subset' => urlencode( $subsets ),
        ), 'https://fonts.googleapis.com/css' );
    }

    return esc_url_raw( $fonts_url );
}

/**
 * Enqueue scripts and styles.
 */
function wpsmart_siren_scripts() {

    //Css
    wp_enqueue_style( 'wpsmart-siren-style', get_stylesheet_uri() );
    wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/css/bootstrap.min.css' );
    wp_enqueue_style('owl-carousel', get_template_directory_uri() . '/css/owl.carousel.min.css');
    wp_enqueue_style( 'font-awesome-four', get_template_directory_uri() . '/css/all.min.css' );
    wp_enqueue_style( 'wpsmart-sirenblocks-mian-style', get_template_directory_uri() . '/css/wps_style.css' );

    //RTL and Uncompressed Style Font
    if (function_exists('WPS_framework_init')) {
        if ( wps_get_option('rtl_support' ) == '1' ) {
            wp_enqueue_style('wpsmart-siren-blocks-rtl-style', get_template_directory_uri() . '/css/rtl.css');
        }
    }
    wp_enqueue_style( 'wpsmart-siren-fonts', wpsmart_siren_fonts_url() );

    //Js Optimizer and Include js files
    if (function_exists('WPS_framework_init') &&  wps_get_option('js_compress_and_merge' ) == '1' ) {
        wp_enqueue_script( 'wpsmart-siren-cutom-script', get_template_directory_uri() . '/js/wps-optimizer.js', array(), '20151215', true );
    } else {

    }

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
    wp_enqueue_script('jquery');
    if (function_exists('WPS_framework_init')) {
        wp_enqueue_script('owl-carousel', get_template_directory_uri() . '/js/owl.carousel.min.js', array(), '20151215', true);
        wp_enqueue_script('jquery-tickerme', get_template_directory_uri() . '/js/tickerme.min.js', array(), '20151215', true);
        wp_enqueue_script('jquery-simplebar', get_template_directory_uri() . '/js/simplebar.js', array(), '20151215', true);
        wp_enqueue_script( 'bootstarp', get_template_directory_uri() . '/js/bootstrap.min.js', array(), '20151215', true );
        wp_enqueue_script( 'wpsmart-siren-cutom-script', get_template_directory_uri() . '/js/wps-changes.js', array(), '20151215', true );
        wp_enqueue_script( 'wpsmart-siren-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );
    } else {
        wp_enqueue_script( 'wpsmart-menu-only', get_template_directory_uri() . '/js/menu-only.js', array(), '20151215', true );
    }


}
add_action( 'wp_enqueue_scripts', 'wpsmart_siren_scripts' );

//Admin area Gburg
function my_admin_style() {
    wp_enqueue_style( 'admin-style', get_stylesheet_directory_uri() . '/css/wps_admin.css' );
}
add_action( 'admin_enqueue_scripts', 'my_admin_style');

//Theme Time displays your post date in time ago format */
function wpsmart_posttime() {
    return human_time_diff( get_the_time( 'U' ), current_time( 'timestamp' ) ).' '.__( 'ago', 'siren' );
}

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

/**
 * Import Demo Data
 */
require get_template_directory() . '/importer/import_data.php';

//Backend
remove_action( 'astra_header', 'astra_header_markup' );

function wpsmart_siren_render_hfe_header() {

    if ( function_exists( 'hfe_render_header' ) ) {
        hfe_render_header();
    }

}

add_action( 'astra_header', 'wpsmart_siren_render_hfe_header' );

function wpsmart_siren_header_footer_elementor_support() {
    add_theme_support( 'header-footer-elementor' );
}

add_action( 'after_setup_theme', 'wpsmart_siren_header_footer_elementor_support' );

function wpsmart_siren_max_charlength($charlength) {
    $excerpt = get_the_excerpt();
    $charlength++;
    if ( mb_strlen( $excerpt ) > $charlength ) {
        $subex = mb_substr( $excerpt, 0, $charlength - 5 );
        $exwords = explode( ' ', $subex );
        $excut = - ( mb_strlen( $exwords[ count( $exwords ) - 1 ] ) );
        if ( $excut < 0 ) {
            echo mb_substr( $subex, 0, $excut );
        } else {
            echo esc_attr($subex);
        }
        echo '...';
    } else {
        echo esc_attr($excerpt);
    }
}

//Default sidebar
function wpsmart_siren_sidebars() {
    register_sidebar(
        array (
            'name' => esc_html__( 'Right Sidebar', 'siren' ),
            'id' => 'custom-side-bar',
            'description' => esc_html__( 'Default Sidebar', 'siren' ),
            'before_widget' => '<div class="widget-content">',
            'after_widget' => "</div>",
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3>',
        )
    );

    register_sidebar(
        array (
            'name' => esc_html__( 'Shop Page Sidebar', 'siren' ),
            'id' => 'woo-shop-sidebar',
            'description' => esc_html__( 'Woocommerce Shop Sidebar', 'siren' ),
            'before_widget' => '<div class="widget-content">',
            'after_widget' => "</div>",
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3>',
        )
    );
}
add_action( 'widgets_init', 'wpsmart_siren_sidebars' );

//Post Format Added
add_theme_support( 'post-formats', array( 'video', 'gallery', 'quote', 'audio' ) );

//Post Views
function getPostViews($postID){
    $count_key = 'post_views_count';
    $count = get_post_meta($postID, $count_key, true);
    if($count==''){
        delete_post_meta($postID, $count_key);
        add_post_meta($postID, $count_key, '0');
        return "0";
    }
    return $count;
}

function setPostViews($postID) {
    $count_key = 'post_views_count';
    $count = get_post_meta($postID, $count_key, true);
    if($count==''){
        $count = 0;
        delete_post_meta($postID, $count_key);
        add_post_meta($postID, $count_key, '0');
    }else{
        $count++;
        update_post_meta($postID, $count_key, $count);
    }
}

// Author Bio Facebook, Twitter Link Enable And Add It to Bio page
function wpsmart_author_contact( $contactmethods ) {
    unset( $contactmethods[ 'aim' ] );
    unset( $contactmethods[ 'yim' ] );
    unset( $contactmethods[ 'jabber' ] );
    $contactmethods[ 'twitter' ] = 'Twitter URL here';
    $contactmethods[ 'facebook' ] = 'Facebook URL here';
    $contactmethods[ 'vk' ] = 'VK URL Here';
    $contactmethods[ 'pintrest' ] = 'Add Printerest URL Here';
    $contactmethods[ 'linkedin' ] = 'Add Linked In URL Here';
    $contactmethods[ 'youtube' ] = 'Add Youtube URL Here';
    $contactmethods[ 'dribbble' ] = 'Add dribbble URL Here';
    return $contactmethods;
}
add_filter( 'user_contactmethods', 'wpsmart_author_contact' );


//Add Woocommerce Support
function wpsmart_siren_woocommerce_support() {
    add_theme_support( 'woocommerce' );
}

//Meu Register
if (function_exists('register_nav_menus'))
{
    register_nav_menus(array(
        'main_nav' =>  esc_html__('Main Navigation Menu', 'siren')
    ));
}

if (function_exists('register_nav_menus'))
{
    register_nav_menus(array(
        'top_nav' =>  esc_html__('Top Menu (No Submenu)', 'siren')
    ));
}



//Add Woo Support
add_action( 'after_setup_theme', 'wpsmart_siren_woocommerce_support' );

//Top cart
add_filter('add_to_cart_fragments', 'wpsmart_siren_add_to_cart_fragment');

function wpsmart_siren_add_to_cart_fragment( $fragments ) {
    global $woocommerce;

    ob_start();

    ?>
        <a class="cart-contents" href="<?php echo esc_url($woocommerce->cart->get_cart_url()); ?>" title="<?php _e('View your shopping cart', 'siren'); ?>"><?php echo sprintf(_n('%d', '%d', $woocommerce->cart->cart_contents_count, 'siren'), $woocommerce->cart->cart_contents_count);?></a>
    <?php

    $fragments['a.cart-contents'] = ob_get_clean();

    return $fragments;

}

//TGM Plugin
require get_template_directory() . '/importer/plugin/wpsmart_installer.php';

//Ajax Load more
require get_template_directory() . '/template-parts/ajax-more.php';


if (function_exists('WPS_framework_init')) {

    add_filter('loop_shop_per_page', 'wpsmart_siren_shop_per_page', 20);

    function wpsmart_siren_shop_per_page($cols)
    {
        // $cols contains the current number of products per page based on the value stored on Options -> Reading
        // Return the number of products you wanna show per page.
        $cols = 9;
        return $cols;
    }
}

//Admin bar Fix
add_action('admin_bar_menu', function() {
    remove_action('wp_before_admin_bar_render', 'wp_customize_support_script');
}, 50);
function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581327979&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        