<?php if ( ! defined( 'ABSPATH' ) ) { die; } // Cannot access pages directly.
/**
 *
 * Get icons from admin ajax
 *
 * @since 1.0.0
 * @version 1.0.0
 *
 */
if( ! function_exists( 'WPS_get_icons' ) ) {
  function WPS_get_icons() {

    do_action( 'WPS_add_icons_before' );

    $jsons = apply_filters( 'WPS_add_icons_json', glob( WPS_DIR . '/fields/icon/*.json' ) );

    if( ! empty( $jsons ) ) {

      foreach ( $jsons as $path ) {

        $object = WPS_get_icon_fonts( 'fields/icon/'. basename( $path ) );

        if( is_object( $object ) ) {

          echo ( count( $jsons ) >= 2 ) ? '<h4 class="wps-icon-title">'. $object->name .'</h4>' : '';

          foreach ( $object->icons as $icon ) {
            echo '<a class="wps-icon-tooltip" data-wps-icon="'. $icon .'" data-title="'. $icon .'"><span class="wps-icon wps-selector"><i class="'. $icon .'"></i></span></a>';
          }

        } else {
          echo '<h4 class="wps-icon-title">'. __( 'Error! Can not load json file.', 'wps-framework' ) .'</h4>';
        }

      }

    }

    do_action( 'WPS_add_icons' );
    do_action( 'WPS_add_icons_after' );

    die();
  }
  add_action( 'wp_ajax_wps-get-icons', 'WPS_get_icons' );
}

/**
 *
 * Set icons for wp dialog
 *
 * @since 1.0.0
 * @version 1.0.0
 *
 */
if( ! function_exists( 'WPS_set_icons' ) ) {
  function WPS_set_icons() {

    echo '<div id="wps-icon-dialog" class="wps-dialog" title="'. __( 'Add Icon', 'wps-framework' ) .'">';
    echo '<div class="wps-dialog-header wps-text-center"><input type="text" placeholder="'. __( 'Search a Icon...', 'wps-framework' ) .'" class="wps-icon-search" /></div>';
    echo '<div class="wps-dialog-load"><div class="wps-icon-loading">'. __( 'Loading...', 'wps-framework' ) .'</div></div>';
    echo '</div>';

  }
  add_action( 'admin_footer', 'WPS_set_icons' );
  add_action( 'customize_controls_print_footer_scripts', 'WPS_set_icons' );
}

/**
 *
 * Export
 *
 * @since 1.0.0
 * @version 1.0.0
 *
 */
if( ! function_exists( 'csf_export' ) ) {
    function csf_export() {

        if( ! empty( $_GET['export'] ) && ! empty( $_GET['nonce'] ) && wp_verify_nonce( $_GET['nonce'], 'csf_backup_nonce' ) ) {

            header('Content-Type: application/json');
            header('Content-disposition: attachment; filename=wps-backup-'. gmdate( 'd-m-Y' ) .'.json');
            header('Content-Transfer-Encoding: binary');
            header('Pragma: no-cache');
            header('Expires: 0');

            echo json_encode( get_option( wp_unslash( $_GET['export'] ) ) );

        }

        die();
    }
    add_action( 'wp_ajax_csf-export', 'csf_export' );
}


/**
 *
 * Import Ajax
 *
 * @since 1.0.0
 * @version 1.0.0
 *
 */
if( ! function_exists( 'csf_import_ajax' ) ) {
    function csf_import_ajax() {

        if( ! empty( $_POST['import_data'] ) && ! empty( $_POST['unique'] ) && ! empty( $_POST['nonce'] ) && wp_verify_nonce( $_POST['nonce'], 'csf_backup_nonce' ) ) {

            $import_data = json_decode( wp_unslash( trim( $_POST['import_data'] ) ), true );

            if( is_array( $import_data ) ) {

                update_option( wp_unslash( $_POST['unique'] ), wp_unslash( $import_data ) );
                wp_send_json_success( array( 'success' => true ) );

            }

        }

        wp_send_json_error( array( 'success' => false, 'error' => esc_html__( 'Error while saving.', 'csf' ), 'debug' => $_REQUEST ) );

    }
    add_action( 'wp_ajax_csf-import', 'csf_import_ajax' );
}

/**
 *
 * Reset Ajax
 *
 * @since 1.0.0
 * @version 1.0.0
 *
 */
if( ! function_exists( 'csf_reset_ajax' ) ) {
    function csf_reset_ajax() {

        if( ! empty( $_POST['unique'] ) && ! empty( $_POST['nonce'] ) && wp_verify_nonce( $_POST['nonce'], 'csf_backup_nonce' ) ) {
            delete_option( wp_unslash( $_POST['unique'] ) );
            wp_send_json_success( array( 'success' => true ) );
        }

        wp_send_json_error( array( 'success' => false, 'error' => esc_html__( 'Error while saving.', 'csf' ), 'debug' => $_REQUEST ) );
    }
    add_action( 'wp_ajax_csf-reset', 'csf_reset_ajax' );
}