<?php
namespace WpsmartSirenTheme\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Main_hedaer_menu extends Widget_Base {

	public function get_name() {
		return 'main-menu-header';
	}

	public function get_title() {
		return __( 'Main Menu', 'wpsmart-elementor-plugin' );
	}

	public function get_icon() {
		return 'eicon-nav-menu';
	}

	public function get_categories() {
        return [ 'header_and_footer_widget' ];
	}

	public function get_script_depends() {
		return [ 'wpsmart-elementor-plugin' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'wpsmart-elementor-plugin' ),
			]
		);

        $this->add_control(
            'menu_background',
            [
                'label' => __( 'Menu Background Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#333333',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .menu-main-menu-container' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'sub_menu_background',
            [
                'label' => __( 'Sub Menu Background Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#333333',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .menu-main-menu-container ul li .sub-menu' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'menu_default_font_color',
            [
                'label' => __( 'Menu Font Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#b1b1b1',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .menu-main-menu-container ul li a, {{WRAPPER}} .mobile-menu-burger i' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'menu_default_font_hover_color',
            [
                'label' => __( 'Menu Font Hover Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#ffffff',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .menu-main-menu-container ul li:hover a' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'top_mouse_over_border',
            [
                'label' => __( 'Menu Background Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#FC0E0E',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .menu-main-menu-container ul li:hover:before' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'bottom_border_menu_sub',
            [
                'label' => __( 'Sub Menu Bottom Border Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#3e3e3e',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .menu-main-menu-container ul li .sub-menu li' => 'border-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'menu_height',
            [
                'label' => __( 'Menu Height', 'wpsmart-elementor-plugin' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                ],
                'selectors' => [
                    '{{WRAPPER}} .menu-main-menu-container ul li a' => 'line-height: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .menu-main-menu-container ul li .sub-menu' => 'top: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .menu-main-menu-container .mobile-menu-burger i' => 'line-height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();
	}

	protected function render( $instance = [] ) {
		$settings = $this->get_settings_for_display();

        ?>

        <div class="menu-main-menu-container">
            <div class="mobile-menu-burger">
                <i class="fas fa-bars mobile-menu-switch"></i>
            </div>
            <?php
            wp_nav_menu( array(
                'theme_location' => 'main_nav',
                'menu_id'        => 'main-menu-mobile',
            ) );
            ?>
        </div>
        <div class="mobile-menu-section">
            <span class="closing-area"></span>
            <div class="mobile-menu-header">
                <form class="search-box-mobile-menu" action="<?php echo home_url( '/' ); ?>" method="get">
                    <input type="text" name="s" id="search" placeholder="Search and Hit Enter" value="<?php the_search_query(); ?>" />
                </form>
                <i class="fas fa-times close-menu"></i>
            </div>
            <div class="mobile-menu-ss" id="main-mobile-menusc">
                <?php
                wp_nav_menu( array(
                    'theme_location' => 'main_nav',
                    'menu_id'        => 'main-menu',
                ) );
                ?>
            </div>
        </div>


        <?php
	}

	protected function _content_template() {}

    public function render_plain_content( $instance = [] ) {}
}
