<?php
namespace WpsmartSirenTheme\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class seach_box_full extends Widget_Base {

	public function get_name() {
		return 'seach-box-full-scr';
	}

	public function get_title() {
		return __( 'Search Box', 'wpsmart-elementor-plugin' );
	}

	public function get_icon() {
		return 'eicon-search';
	}

	public function get_categories() {
        return [ 'header_and_footer_widget' ];
	}

	public function get_script_depends() {
		return [ 'wpsmart-elementor-plugin' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'wpsmart-elementor-plugin' ),
			]
		);

        $this->add_control(
            'search_text',
            [
                'label' => __( 'Search Text', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Search', 'wpsmart-elementor-plugin' ),
                'placeholder' => __( 'Type your title here', 'wpsmart-elementor-plugin' ),
            ]
        );

        $this->add_control(
            'main_background_color',
            [
                'label' => __( 'Search Box Background', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#353535',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .main-search-box' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'search_box_bg',
            [
                'label' => __( 'Search area Background', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#333',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .main-search-box form input ' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'search_box_border',
            [
                'label' => __( 'Search area Background', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#000',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .main-search-box form input' => 'border-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'search_box_font_color',
            [
                'label' => __( 'Search area font color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#ffffff',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .main-search-box form input' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'search-box-height-padding',
            [
                'label' => __( 'Search Box Padding', 'wpsmart-elementor-plugin' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 10,
                        'step' => 1,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 14,
                ],
                'selectors' => [
                    '{{WRAPPER}} .main-search-box' => 'padding: {{SIZE}}{{UNIT}};',
                ],
            ]
        );


        $this->add_control(
            'search_box_border_radius',
            [
                'label' => __( 'Search Box Radius', 'wpsmart-elementor-plugin' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 14,
                ],
                'selectors' => [
                    '{{WRAPPER}} .main-search-box form input' => 'border-radius: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'box_height',
            [
                'label' => __( 'Search Box Height', 'wpsmart-elementor-plugin' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 14,
                ],
                'selectors' => [
                    '{{WRAPPER}} .main-search-box form input' => 'line-height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();
	}

	protected function render( $instance = [] ) {
		$settings = $this->get_settings_for_display();

        ?>

        <?php if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) { ?>
			<div class="main-search-box">
				<form role="search" method="get" action="<?php echo home_url( '/' ); ?>">
					<input type="text" value="" placeholder="<?php echo $settings['search_text']; ?>" name="s" />
				</form>
			</div>
        <?php } else {?>
			<div class="main-search-box" style="color: <?php echo $settings['main_background_color']; ?>;">
				<form role="search" method="get" action="<?php echo home_url( '/' ); ?>">
					<input type="text" value="" style="color: <?php echo $settings['search_box_font_color']; ?>; line-height: <?php echo $settings['box_height']['size']; echo $settings['box_height']['unit']; ?>;  background: <?php echo $settings['search_box_bg']; ?>; border-color: <?php echo $settings['search_box_border']; ?>; border-radius: <?php echo $settings['search_box_border_radius']['size'];  echo $settings['search_box_border_radius']['unit']; ?>;" placeholder="<?php echo $settings['search_text']; ?>" name="s" />
				</form>
			</div>
        <?php } ?>
        <?php
	}

	protected function _content_template() {}

    public function render_plain_content( $instance = [] ) {}
}
