<?php
namespace WpsmartSirenTheme\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Top_menu_home extends Widget_Base {

	public function get_name() {
		return 'top-menu-header';
	}

	public function get_title() {
		return __( 'Top Menu', 'wpsmart-elementor-plugin' );
	}

	public function get_icon() {
		return 'eicon-nav-menu';
	}

	public function get_categories() {
        return [ 'header_and_footer_widget' ];
	}

	public function get_script_depends() {
		return [ 'wpsmart-elementor-plugin' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'wpsmart-elementor-plugin' ),
			]
		);

        $this->add_control(
            'width',
            [
                'label' => __( 'Menu Height', 'wpsmart-elementor-plugin' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 80,
                        'step' => 1,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                ],
                'selectors' => [
                    '{{WRAPPER}} .top-header-menu ul li a, {{WRAPPER}} .mobile-menu-burger i' => 'line-height: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .link-menu ul' => 'top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'menu_background',
            [
                'label' => __( 'Menu Background Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#ffffff',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .top-header-menu' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'menu_default_font_color',
            [
                'label' => __( 'Menu Font Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => 'rgba(0, 0, 0, 0.37)',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .top-header-menu ul li a' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'menu_default_font_hover_color',
            [
                'label' => __( 'Menu Font Hover Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#000',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .top-header-menu ul li:hover a' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section();
	}

	protected function render( $instance = [] ) {
		$settings = $this->get_settings_for_display();

        ?>
        <div class="mobile-menu-burger top-menu-bg float-left">
            <i class="fas fa-bars top-mobile-menu-switch float-left"></i>
        </div>
        <div class="top-header-menu link-menu">
            <?php
            wp_nav_menu( array(
                'theme_location' => 'top_nav',
                'menu_id'        => 'primary-menu',
            ) );
            ?>
        </div>


        <?php
	}

	protected function _content_template() {}

    public function render_plain_content( $instance = [] ) {}
}
