<?php
namespace WpsmartSirenTheme\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Comment_single_block extends Widget_Base {

    public function get_name() {
        return 'comment-single-page';
    }

    public function get_title() {
        return __( 'Comments', 'wpsmart-elementor-plugin' );
    }

    public function get_icon() {
        return ' eicon-comments';
    }

    public function get_categories() {
        return [ 'wpsmart-post-widget' ];
    }

    public function get_script_depends() {
        return [ 'wpsmart-elementor-plugin' ];
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'section_content',
            [
                'label' => __( 'Content', 'wpsmart-elementor-plugin' ),
            ]
        );

        $this->add_control(
            'enable_default_wordpress_comment',
            [
                'label' => __( 'Enable/Disable Default Comment', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Enable', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Disable', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'wp_default_tab_title',
            [
                'label' => __( 'Tab Title For Default Comment', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Comment Using Wordpress', 'wpsmart-elementor-plugin' ),
            ]
        );


        $this->add_control(
            'enable_facebook_comment',
            [
                'label' => __( 'Enable/Disable Facebook Comment', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Enable', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Disable', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

        $this->add_control(
            'facebook_app_id_here',
            [
                'label' => __( 'Facebook App ID', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( '340889566542336', 'wpsmart-elementor-plugin' ),
                'placeholder' => __( '340889566542336', 'wpsmart-elementor-plugin' ),
            ]
        );

        $this->add_control(
            'fb_default_tab_title',
            [
                'label' => __( 'Tab Title For Facebook Comment', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Comment Using Wordpress', 'wpsmart-elementor-plugin' ),
            ]
        );

        $this->end_controls_section();
    }

    protected function render( $instance = [] ) {
        $settings = $this->get_settings_for_display();
        $dirplugin = plugins_url();
        if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) { ?>
            <div class="main-comment-panel">
                <ul class="nav nav-tabs">
                    <?php if ( 'yes' === $settings['enable_default_wordpress_comment'] ) { ?>
                    <li class="active"><a data-toggle="tab" href="#wordpress"><?php echo $settings['wp_default_tab_title']?></a></li>
                    <?php } ?>
                    <?php if ( 'yes' === $settings['enable_facebook_comment'] ) { ?>
                    <li><a data-toggle="tab" href="#facebook_comment"><?php echo $settings['fb_default_tab_title']?></a></li>
                    <?php } ?>
                </ul>
                <div class="tab-content">
                    <?php if ( 'yes' === $settings['enable_default_wordpress_comment'] ) { ?>
                    <div id="wordpress" class="tab-pane fade in active">
                        <div class="comment-template">
                            <div class="comment-template">
                                <div id="comments" class="comments-area">
                                    <h2 class="comments-title">
                                        5 thoughts on “<span>This BlogPost Title</span>”
                                    </h2><!-- .comments-title -->
                                    <ol class="comment-list">
                                        <li id="comment-3" class="comment byuser comment-author-admin bypostauthor even thread-even depth-1 parent">
                                            <article id="div-comment-3" class="comment-body">
                                                <footer class="comment-meta">
                                                    <div class="comment-author vcard">
                                                        <img alt="" src="<?php echo $dirplugin;?>/wpsmart_siren/assets/img/profile.png" srcset="<?php echo $dirplugin;?>/wpsmart_siren/assets/img/profile.png" class="avatar avatar-32 photo" height="32" width="32">
                                                        <b class="fn">Johnathan</b> <span class="says">says:</span>
                                                    </div><!-- .comment-author -->
                                                    <div class="comment-metadata">
                                                        <a href="">
                                                            <time datetime="2019-05-15T11:48:20+00:00">
                                                                May 15, 2019 at 11:48 am
                                                            </time>
                                                        </a>
                                                    </div><!-- .comment-metadata -->
                                                </footer><!-- .comment-meta -->
                                                <div class="comment-content">
                                                    <p>Sample Comment</p>
                                                </div><!-- .comment-content -->
                                                <div class="reply"><a rel="nofollow" class="comment-reply-link" href="" data-commentid="3" data-postid="485" data-belowelement="div-comment-3" data-respondelement="respond" aria-label="Reply to admin">Reply</a></div>			</article><!-- .comment-body -->
                                            <ol class="children">
                                                <li id="comment-5" class="comment byuser comment-author-admin bypostauthor odd alt depth-2 parent">
                                                    <article id="div-comment-5" class="comment-body">
                                                        <footer class="comment-meta">
                                                            <div class="comment-author vcard">
                                                                <img alt="" src="<?php echo $dirplugin;?>/wpsmart_siren/assets/img/profile.png" srcset="<?php echo $dirplugin;?>/wpsmart_siren/assets/img/profile.png" class="avatar avatar-32 photo" height="32" width="32">
                                                                <b class="fn">Amanda </b> <span class="says">says:</span>
                                                            </div><!-- .comment-author -->
                                                            <div class="comment-metadata">
                                                                <a href="#">
                                                                    <time datetime="2019-05-15T11:49:08+00:00">
                                                                        May 15, 2019 at 11:49 am
                                                                    </time>
                                                                </a>
                                                            </div><!-- .comment-metadata -->

                                                        </footer><!-- .comment-meta -->
                                                        <div class="comment-content">
                                                            <p>Comment Reply One</p>
                                                        </div><!-- .comment-content -->
                                                        <div class="reply"><a rel="nofollow" class="comment-reply-link" href="#" data-commentid="5" data-postid="485" data-belowelement="div-comment-5" data-respondelement="respond" aria-label="Reply to admin">Reply</a>
                                                        </div>
                                                    </article><!-- .comment-body -->
                                                    <ol class="children">
                                                        <li id="comment-6" class="comment byuser comment-author-admin bypostauthor even depth-3">
                                                            <article id="div-comment-6" class="comment-body">
                                                                <footer class="comment-meta">
                                                                    <div class="comment-author vcard">
                                                                        <img alt="" src="<?php echo $dirplugin;?>/wpsmart_siren/assets/img/profile.png" srcset="<?php echo $dirplugin;?>/wpsmart_siren/assets/img/profile.png" class="avatar avatar-32 photo" height="32" width="32">
                                                                        <b class="fn">Diane </b> <span class="says">says:</span>
                                                                    </div><!-- .comment-author -->
                                                                    <div class="comment-metadata">
                                                                        <a href="#">
                                                                            <time datetime="2019-05-15T11:49:18+00:00">
                                                                                May 15, 2019 at 11:49 am
                                                                            </time>
                                                                        </a>
                                                                    </div><!-- .comment-metadata -->
                                                                </footer><!-- .comment-meta -->

                                                                <div class="comment-content">
                                                                    <p>It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout. The point of using Lorem Ipsum is that it has a more-or-less normal distribution of letters, as opposed to using ‘Content here, content here’, making it look like readable English.</p>
                                                                </div><!-- .comment-content -->
                                                                <div class="reply">
                                                                    <a rel="nofollow" class="comment-reply-link" href="#" data-commentid="6" data-postid="485" data-belowelement="div-comment-6" data-respondelement="respond" aria-label="Reply to admin">Reply</a>
                                                                </div>
                                                            </article><!-- .comment-body -->
                                                        </li><!-- #comment-## -->
                                                    </ol><!-- .children -->
                                                </li><!-- #comment-## -->
                                            </ol><!-- .children -->
                                        </li><!-- #comment-## -->
                                        <li id="comment-4" class="comment byuser comment-author-admin bypostauthor odd alt thread-odd thread-alt depth-1">
                                            <article id="div-comment-4" class="comment-body">
                                                <footer class="comment-meta">
                                                    <div class="comment-author vcard">
                                                        <img alt="" src="<?php echo $dirplugin;?>/wpsmart_siren/assets/img/profile.png" srcset="<?php echo $dirplugin;?>/wpsmart_siren/assets/img/profile.png" class="avatar avatar-32 photo" height="32" width="32">
                                                        <b class="fn">James </b> <span class="says">says:</span>
                                                    </div><!-- .comment-author -->
                                                    <div class="comment-metadata">
                                                        <a href="#">
                                                            <time datetime="2019-05-15T11:48:52+00:00">
                                                                May 15, 2019 at 11:48 am
                                                            </time>
                                                        </a>
                                                    </div><!-- .comment-metadata -->
                                                </footer><!-- .comment-meta -->
                                                <div class="comment-content">
                                                    <p>Sample comment Long</p>
                                                    <p>It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout. The point of using Lorem Ipsum is that it has a more-or-less normal distribution of letters, as opposed to using ‘Content here, content here’, making it look like readable English.</p>
                                                </div><!-- .comment-content -->
                                                <div class="reply"><a rel="nofollow" class="comment-reply-link" href="#" data-commentid="4" data-postid="485" data-belowelement="div-comment-4" data-respondelement="respond" aria-label="Reply to admin">Reply</a>
                                                </div>
                                            </article><!-- .comment-body -->
                                        </li><!-- #comment-## -->
                                        <li id="comment-10" class="comment byuser comment-author-admin bypostauthor even thread-even depth-1">
                                            <article id="div-comment-10" class="comment-body">
                                                <footer class="comment-meta">
                                                    <div class="comment-author vcard">
                                                        <img alt="" src="<?php echo $dirplugin;?>/wpsmart_siren/assets/img/profile.png" srcset="<?php echo $dirplugin;?>/wpsmart_siren/assets/img/profile.png" class="avatar avatar-32 photo" height="32" width="32">
                                                        <b class="fn">Jack </b> <span class="says">says:</span>
                                                    </div><!-- .comment-author -->
                                                    <div class="comment-metadata">
                                                        <a href="#">
                                                            <time datetime="2019-05-27T14:49:09+00:00">
                                                                May 27, 2019 at 2:49 pm
                                                            </time>
                                                        </a>
                                                    </div><!-- .comment-metadata -->
                                                </footer><!-- .comment-meta -->
                                                <div class="comment-content">
                                                    <p>It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout. The point of using Lorem Ipsum is that it has a more-or-less normal distribution of letters, as opposed to using ‘Content here, content here’, making it look like readable English.</p>
                                                </div><!-- .comment-content -->
                                                <div class="reply"><a rel="nofollow" class="comment-reply-link" href="#" data-commentid="10" data-postid="485" data-belowelement="div-comment-10" data-respondelement="respond" aria-label="Reply to admin">Reply</a></div>			</article><!-- .comment-body -->
                                        </li><!-- #comment-## -->
                                    </ol><!-- .comment-list -->
                                    <div id="respond" class="comment-respond">
                                        <h3 id="reply-title" class="comment-reply-title">Leave a Reply <small><a rel="nofollow" id="cancel-comment-reply-link" href="#" style="display:none;">Cancel reply</a></small></h3>			<form action="http://localhost/wordpress/wp-comments-post.php" method="post" id="commentform" class="comment-form" novalidate="">
                                            <p class="comment-notes"><span id="email-notes">Your email address will not be published.</span> Required fields are marked <span class="required">*</span></p><p class="comment-form-comment"><label for="comment">Comment</label> <textarea id="comment" name="comment" cols="45" rows="8" maxlength="65525" required="required"></textarea></p><p class="comment-form-author"><label for="author">Name <span class="required">*</span></label> <input id="author" name="author" type="text" value="" size="30" maxlength="245" required="required"></p>
                                            <p class="comment-form-email"><label for="email">Email <span class="required">*</span></label> <input id="email" name="email" type="email" value="" size="30" maxlength="100" aria-describedby="email-notes" required="required"></p>
                                            <p class="comment-form-url"><label for="url">Website</label> <input id="url" name="url" type="url" value="" size="30" maxlength="200"></p>
                                            <p class="form-submit"><input name="submit" type="submit" id="submit" class="submit" value="Post Comment"> <input type="hidden" name="comment_post_ID" value="485" id="comment_post_ID">
                                                <input type="hidden" name="comment_parent" id="comment_parent" value="0">
                                            </p>			</form>
                                    </div><!-- #respond -->
                                </div><!-- #comments -->
                            </div>
                        </div>
                    </div>
                    <?php } ?>
                    <?php if ( 'yes' === $settings['enable_facebook_comment'] ) { ?>
                    <div id="facebook_comment" class="tab-pane fade">
                        <div class="facebook-comment">
                            <div id="fb-root"></div>
                            <script async defer crossorigin="anonymous" src="https://connect.facebook.net/en_US/sdk.js#xfbml=1&version=v3.3&appId=<?php echo $settings['facebook_app_id_here']?>&autoLogAppEvents=1"></script>
                            <div class="fb-comments" data-href="<?php the_permalink(); ?>" data-width="100%"  data-numposts="5"></div>
                        </div>
                    </div>
                    <?php } ?>
                </div>
            </div>
        <?php } else {?>
            <div class="main-comment-panel">
                <ul class="nav nav-tabs">
                    <?php if ( 'yes' === $settings['enable_default_wordpress_comment'] ) { ?>
                        <li class="active"><a data-toggle="tab" href="#wordpress"><?php echo $settings['wp_default_tab_title']?></a></li>
                    <?php } ?>
                    <?php if ( 'yes' === $settings['enable_facebook_comment'] ) { ?>
                        <li><a data-toggle="tab" href="#facebook_comment"><?php echo $settings['fb_default_tab_title']?></a></li>
                    <?php } ?>
                </ul>
                <div class="tab-content">
                    <?php if ( 'yes' === $settings['enable_default_wordpress_comment'] ) { ?>
                        <div id="wordpress" class="tab-pane fade in active">
                            <div class="comment-template">
                                <?php comments_template(); ?>
                            </div>
                        </div>
                    <?php } ?>
                    <?php if ( 'yes' === $settings['enable_facebook_comment'] ) { ?>
                        <div id="facebook_comment" class="tab-pane fade">
                            <div class="facebook-comment">
                                <div id="fb-root"></div>
                                <script async defer crossorigin="anonymous" src="https://connect.facebook.net/en_US/sdk.js#xfbml=1&version=v3.3&appId=<?php echo $settings['facebook_app_id_here']?>&autoLogAppEvents=1"></script>
                                <div class="fb-comments" data-href="<?php the_permalink(); ?>" data-width="100%"  data-numposts="5"></div>
                            </div>
                        </div>
                    <?php } ?>
                </div>
            </div>
            <?php
        }
    }

    protected function _content_template() {}

    public function render_plain_content( $instance = [] ) {}

}
