<?php
namespace WpsmartSirenTheme\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Featured_post_single extends Widget_Base {

    public function get_name() {
        return 'featured-post-thumbnail';
    }

    public function get_title() {
        return __( 'Featured Thumbnail', 'wpsmart-elementor-plugin' );
    }

    public function get_icon() {
        return ' eicon-featured-image';
    }

    public function get_categories() {
        return [ 'wpsmart-post-widget' ];
    }

    public function get_script_depends() {
        return [ 'wpsmart-elementor-plugin' ];
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'section_content',
            [
                'label' => __( 'Content', 'wpsmart-elementor-plugin' ),
            ]
        );

        $this->add_control(
            'post_font_size',
            [
                'label' => __( 'Change Font size', 'wpsmart-elementor-plugin' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 100,
                        'max' => 600,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => '%',
                    'size' => 35,
                ],
                'selectors' => [
                    '{{WRAPPER}} .featured-image:before' => 'padding-top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );


        $this->end_controls_section();
    }

    protected function render( $instance = [] ) {
        $settings = $this->get_settings_for_display();
        $dirplugin = plugins_url();
        if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) { ?>
            <div class="featured-image">
                <img src="<?php echo $dirplugin;?>/wpsmart_siren/assets/img/post-thumbnail.jpg" alt="">
            </div>
        <?php } else { ?>
            <?php if ( has_post_thumbnail() ) { ?>
            <div class="featured-image">
                <?php
                if ( get_post_type( get_the_ID() ) == 'ae_global_templates' ) { ?>
                    <img src="<?php echo $dirplugin;?>/wpsmart_siren/assets/img/post-thumbnail.jpg" alt="">
                <?php } else {
                    $meta_value = get_post_meta ( get_the_ID(), 'siren_metadata', true );
                    if ($meta_value['youtube_video_url'] ) {?>
                        <iframe type="text/html"
                                src="<?php echo $meta_value['youtube_video_url']; ?>?modestbranding=1&autohide=1&showinfo=0&controls=0"
                                frameborder="0"></iframe>
                    <?php } else if ( $meta_value['upload_preview_video'] ) {?>
                        <video loop autoplay muted>
                            <source src="<?php echo $meta_value['upload_preview_video']; ?>" type="video/mp4">
                            <source src="<?php echo $meta_value['upload_preview_video']; ?>" type="video/ogg">
                        </video>
                    <?php } else { ?>
                        <?php the_post_thumbnail(); ?>
                    <?php }
                }
                ?>
            </div>
            <?php } ?>
        <?php
        }
    }

    protected function _content_template() {}

    public function render_plain_content( $instance = [] ) {}

}
