<?php
namespace WpsmartSirenTheme\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Post_author_block extends Widget_Base {

    public function get_name() {
        return 'post-author-single-block';
    }

    public function get_title() {
        return __( 'Post Author', 'wpsmart-elementor-plugin' );
    }

    public function get_icon() {
        return 'eicon-lock-user';
    }

    public function get_categories() {
        return [ 'wpsmart-post-widget' ];
    }

    public function get_script_depends() {
        return [ 'wpsmart-elementor-plugin' ];
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'section_content',
            [
                'label' => __( 'Content', 'wpsmart-elementor-plugin' ),
            ]
        );

        $this->add_control(
            'box-style-enable',
            [
                'label' => __( 'Card Style Enable', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Enable', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Disable', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

        $this->end_controls_section();
    }

    protected function render( $instance = [] ) {
        $settings = $this->get_settings_for_display();
        if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) { ?>

        <?php } else {?>
            <div class="post-author-template">
                <div class="postauth">
                    <div class="image-side">
                        <?php echo get_avatar( get_the_author_meta( 'ID' ), '150' ); ?>
                    </div>
                    <div class="auth-content">
                        <h2 class="main-author"><?php the_author(); ?></h2>
                        <?php echo wp_kses( get_the_author_meta( 'description' ), null ); ?>
                        <div class="social-icons">
                            <?php if ( get_the_author_meta( 'twitter' ) != '' )  { ?>
                                <a class="twitter-link" href="<?php echo wp_kses( get_the_author_meta( 'twitter' ), null ); ?>" target="_blank">
                                    <i class="fab fa-twitter"></i>
                                </a>
                            <?php } ?>

                            <?php if ( get_the_author_meta( 'facebook' ) != '' )  { ?>
                                <a class="facebook-link" href="<?php echo wp_kses( get_the_author_meta( 'facebook' ), null ); ?>" target="_blank">
                                    <i class="fab fa-facebook-f"></i>
                                </a>
                            <?php } ?>

                            <?php if ( get_the_author_meta( 'vk' ) != '' )  { ?>
                                <a class="google-link" href="<?php echo wp_kses( get_the_author_meta( 'vk' ), null ); ?>" target="_blank">
                                    <i class="fab fa-vk"></i>
                                </a>
                            <?php } ?>

                            <?php if ( get_the_author_meta( 'pintrest' ) != '' )  { ?>
                                <a class="pintrest-link" href="<?php echo wp_kses( get_the_author_meta( 'pintrest' ), null ); ?>" target="_blank">
                                    <i class="fab fa-pinterest-p"></i>
                                </a>
                            <?php } ?>

                            <?php if ( get_the_author_meta( 'linkedin' ) != '' )  { ?>
                                <a class="linkedin-link" href="<?php echo wp_kses( get_the_author_meta( 'linkedin' ), null ); ?>" target="_blank">
                                    <i class="fab fa-linkedin-in"></i>
                                </a>
                            <?php } ?>

                            <?php if ( get_the_author_meta( 'youtube' ) != '' )  { ?>
                                <a class="youtubevid-link" href="<?php echo wp_kses( get_the_author_meta( 'youtube' ), null ); ?>" target="_blank">
                                    <i class="fab fa-youtube"></i>
                                </a>
                            <?php } ?>

                            <?php if ( get_the_author_meta( 'dribbble' ) != '' )  { ?>
                                <a class="dribbble-link" href="<?php echo wp_kses( get_the_author_meta( 'dribbble' ), null ); ?>" target="_blank">
                                    <i class="fab fa-dribbble"></i>
                                </a>
                            <?php } ?>
                        </div>
                    </div>
                </div>
            </div>
        <?php
        }
    }

    protected function _content_template() {}

    public function render_plain_content( $instance = [] ) {}

}
