<?php
namespace WpsmartSirenTheme\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Ajax_post_load extends Widget_Base {

	public function get_name() {
		return 'ajax-archive-post';
	}
	public function get_title() {
		return __( 'Ajax  Recent Post', 'wpsmart-elementor-plugin' );
	}
	public function get_icon() {
		return 'eicon-download-button';
	}
	public function get_categories() {
        return [ 'wpsmart-widget' ];
	}
	public function get_script_depends() {
		return [ 'wpsmart-elementor-plugin' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'wpsmart-elementor-plugin' ),
			]
		);

        $this->add_control(
            'widget_title',
            [
                'label' => __( 'Title', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Default title', 'wpsmart-elementor-plugin' ),
                'placeholder' => __( 'Type your title here', 'wpsmart-elementor-plugin' ),
            ]
        );

        $this->add_control(
            'widget_sub_title',
            [
                'label' => __( 'Sub Title', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Default sub title', 'wpsmart-elementor-plugin' ),
                'placeholder' => __( 'Type your sub-title here', 'wpsmart-elementor-plugin' ),
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => __( 'Main Title Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => 'rgba(0, 0, 0, 0.87)',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .widget-title-section .titles-pack .main-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'sub_title_color',
            [
                'label' => __( 'Sub Title Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => 'rgba(0, 0, 0, 0.54)',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .widget-title-section .titles-pack .sub-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'title_border_color',
            [
                'label' => __( 'Title Bottom Border Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#FC0E0E',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .widget-title-section .titles-pack .main-title .bottom-border' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'word_trim',
            [
                'label' => __( 'How many Words For Content', 'plugin-domain' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'min' => 5,
                'max' => 60,
                'step' => 1,
                'default' => 40,
            ]
        );

        $this->add_control(
            'show_post_view',
            [
                'label' => __( 'Show Posted Views', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Hide', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'show_posted_date',
            [
                'label' => __( 'Show Post Date', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Hide', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'show_hide_comment_count',
            [
                'label' => __( 'Show Comment Count Date', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Hide', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

		$this->end_controls_section();

		//Style Section
		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Style', 'wpsmart-elementor-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

        $this->add_control(
            'simple_style',
            [
                'label' => __( 'Simple Style Enable', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Enable', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Disable', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );


        $this->add_control(
            'box-style-enable',
            [
                'label' => __( 'Card Style Enable', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Enable', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Disable', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

        $this->add_control(
            'dark_theme_active',
            [
                'label' => __( 'Dark Theme Activate Enable', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Enable', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Disable', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

		$this->end_controls_section();
	}

	protected function render( $instance = [] ) {
		$settings = $this->get_settings_for_display();
        ?>

        <div class="ajax-post-archive <?php if ( 'yes' === $settings['box-style-enable'] ) { ?> card-design <?php } ?> <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> dark-mood-active <?php } ?> <?php if ( 'yes' === $settings['simple_style'] ) { ?> simple-style <?php } ?>">
            <?php   if ($settings['widget_title']) { ?>
            <div class="widget-title-section <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>">
                <div class="titles-pack">
                    <?php if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) { ?>
                        <h2 class="main-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>"><?php echo $settings['widget_title'] ?>
                            <span class="bottom-border"></span>
                        </h2>
                        <span class="sub-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>"><?php echo $settings['widget_sub_title'] ?></span>
                    <?php } else {?>
                        <h2 class="main-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>" style="color: <?php echo $settings['title_color']; ?>;">
                            <?php echo $settings['widget_title'] ?>
                            <span class="bottom-border" style="background: <?php echo $settings['title_border_color']; ?>;"></span>
                        </h2>
                        <span class="sub-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>" style="color: <?php echo $settings['sub_title_color']; ?>;"><?php echo $settings['widget_sub_title'] ?></span>
                    <?php } ?>
                </div>
                <div class="title-options">
                    <span class="more <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?> icon">
                       <i class="far fa-newspaper"></i>
                    </span>
                </div>
            </div>
            <?php } ?>
            <?php
            $args = array(
                'post_type' => 'post',
                'post_status' => 'publish',
                'posts_per_page' => '5',
                'paged' => 1,
            );
            $my_posts = new \WP_Query( $args );
            if ( $my_posts->have_posts() ) :
            ?>
            <div class="wps-loader-posts">
                <?php while ( $my_posts->have_posts() ) : $my_posts->the_post(); ?>
                    <div class="archive-post-section">
                        <div class="content-and-meta">
                            <div class="mets-and-ttl">
                                <?php
                                $post_tags = get_the_tags();
                                $mysettings = get_term_meta( $post_tags[0]->term_id, 'custom_taxonomy_options', true );
                                if ($post_tags) { ?>
                                    <?php if ( 'yes' === $settings['simple_style'] ) { ?>
                                        <div class="single-post-mid">
                                             <span class="small-post-tag-x" <?php if (!empty($mysettings['custom_tag_color'])) { ?> style="background: <?php echo $mysettings['custom_tag_color']; ?>; color: <?php echo $mysettings['custom_tag_font_color']; ?>;" <?php } ?>>
                                             <?php
                                             $string = $post_tags[0]->name;
                                             $firstCharacter = mb_substr($string,0,1,'utf-8');
                                             echo _($firstCharacter);
                                             ?>
                                            </span>
                                            <span class="simple-font-x">
                                                 <?php
                                                 echo $post_tags[0]->name;
                                                 ?>
                                            </span>
                                        </div>
                                    <?php } else { ?>
                                        <span class="small-post-tag-x" <?php if (!empty($mysettings['custom_tag_color'])) { ?> style="background: <?php echo $mysettings['custom_tag_color']; ?>; color: <?php echo $mysettings['custom_tag_font_color']; ?>;" <?php } ?>>
                                             <?php
                                             $string = $post_tags[0]->name;
                                             $firstCharacter = mb_substr($string,0,1,'utf-8');
                                             echo _($firstCharacter);
                                             ?>
                                        </span>
                                        <span class="simple-font-x">
                                             <?php
                                             echo $post_tags[0]->name;
                                             ?>
                                        </span>
                                    <?php } ?>
                                <?php } ?>
                                <a href="<?php the_permalink(); ?>">
                                    <h2><?php the_title(); ?></h2>
                                </a>
                                <div class="post-meta">
                                    <?php if ( 'yes' === $settings['show_posted_date'] ) { ?>
                                    <div class="post-time">
                                        <i class="far fa-clock"></i> <?php echo wpsmart_posttime(); ?>
                                    </div>
                                    <?php } ?>
                                    <?php if ( 'yes' === $settings['show_post_view'] ) { ?>
                                    <div class="post-view">
                                        <i class="fas fa-eye"></i> <?php echo getPostViews(get_the_ID()); ?>
                                    </div>
                                    <?php } ?>
                                    <?php if ( 'yes' === $settings['show_hide_comment_count'] ) { ?>
                                    <div class="comment-count">
                                        <a href="<?php the_permalink(); ?>">
                                            <i class="far fa-comment"></i> <?php echo $my_posts->comment_count; ?>
                                        </a>
                                    </div>
                                    <?php } ?>
                                </div>
                            </div>
                            <div class="post-content-wrap">
                                <p>
                                    <?php
                                    $content_count = $settings['word_trim'];
                                    echo wp_trim_words( get_the_content(), $content_count, '...' );
                                    ?>
                                </p>
                            </div>
                        </div>
                        <div class="post-image-thumb">
                            <div class="share-buttons-home small-share">
                                <a target="_blank" class="fb-share" href="https://www.facebook.com/sharer/sharer.php?u=<?php the_permalink(); ?>">
                                    <i class="fab fa-facebook-f"></i>
                                </a>
                                <a target="_blank" href="//pinterest.com/pin/create/link/?url=<?php the_permalink();?>&amp;description=<?php $shareblettl =  get_the_title(); echo str_replace(" ", "%20", $shareblettl); ?>" class="pin-share">
                                    <i class="fab fa-pinterest-p"></i>
                                </a>
                                <a target="_blank" href="https://twitter.com/intent/tweet?url=<?php the_permalink(); ?>&text=<?php $shareblettl =  get_the_title(); echo str_replace(" ", "%20", $shareblettl); ?>" class="tw-share">
                                    <i class="fab fa-twitter"></i>
                                </a>
                            </div>
                            <?php if ( has_post_format( 'video' )) { ?>
                                <i class="post-by-type fas fa-video"></i>
                            <?php } else if ( has_post_format( 'gallery' )) { ?>
                                <i class="post-by-type fas fa-images"></i>
                            <?php } else if ( has_post_format( 'quote' )) { ?>
                                <i class="post-by-type fas fa-quote-right"></i>
                            <?php } else if ( has_post_format( 'audio' )) { ?>
                                <i class="post-by-type fab fa-itunes-note"></i>
                            <?php }?>
                            <?php the_post_thumbnail('siren-medium-post-thumb'); ?>
                            <div class="popup-andlink">
                                <?php if ( has_post_thumbnail() ) { ?>
                                    <span class="preview-text">
                                        <?php $feat_image_url = wp_get_attachment_url( get_post_thumbnail_id() ); ?>
                                        <a href="<?php echo $feat_image_url ?>" class="open-lightbox">
                                        <?php echo esc_attr_e( 'Preview', 'siren' ); ?>
                                        </a>
                                    </span>
                                <?php } ?>
                                <div class="main-link">
                                    <a href="<?php the_permalink(); ?>" target="_blank">
                                        <i class="fas fa-external-link-alt"></i>
                                    </a>
                                </div>
                            </div>
                        </div>
                    </div>
                <?php endwhile; ?>
            </div>
            <div class="load-this-more">
                <div class="loadmore"><?php echo esc_attr_e( 'Load More', 'siren' ); ?></div>
            </div>
            <?php endif; ?>
        </div>

        <script type="text/javascript">
            var ajaxurl = "<?php echo admin_url( 'admin-ajax.php' ); ?>";
            var page = 2;
            jQuery(function($) {
                $('body').on('click', '.loadmore', function() {
                    var data = {
                        'action': 'load_posts_by_ajax',
                        'page': page,
                        'security': '<?php echo wp_create_nonce("load_more_posts"); ?>'
                    };
                    $.post(ajaxurl, data, function(response) {
                        if(response != '') {
                            $('.wps-loader-posts').append(response);
                            page++;
                        } else {
                            $('.loadmore').hide();
                        }
                    });
                });
            });
        </script>

        <?php
	}

	protected function _content_template() {}

    public function render_plain_content( $instance = [] ) {}
}
