<?php
namespace WpsmartSirenTheme\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Featured_post_by_cat extends Widget_Base {

	public function get_name() {
		return 'featured-post-by-category';
	}
	public function get_title() {
		return __( 'Featured Post Magazine', 'wpsmart-elementor-plugin' );
	}
	public function get_icon() {
		return 'tts eicon-posts-ticker';
	}
	public function get_categories() {
		return [ 'wpsmart-widget' ];
	}
	public function get_script_depends() {
		return [ 'wpsmart-elementor-plugin' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'wpsmart-elementor-plugin' ),
			]
		);

        $this->add_control(
            'widget_title',
            [
                'label' => __( 'Title', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Default title', 'wpsmart-elementor-plugin' ),
                'placeholder' => __( 'Type your title here', 'wpsmart-elementor-plugin' ),
            ]
        );

        $this->add_control(
            'widget_sub_title',
            [
                'label' => __( 'Sub Title', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Default sub title', 'wpsmart-elementor-plugin' ),
                'placeholder' => __( 'Type your sub-title here', 'wpsmart-elementor-plugin' ),
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => __( 'Main Title Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => 'rgba(0, 0, 0, 0.87)',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .widget-title-section .titles-pack .main-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'sub_title_color',
            [
                'label' => __( 'Sub Title Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => 'rgba(0, 0, 0, 0.54)',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .widget-title-section .titles-pack .sub-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'title_border_color',
            [
                'label' => __( 'Title Bottom Border Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#FC0E0E',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .widget-title-section .titles-pack .main-title .bottom-border' => 'background: {{VALUE}}',
                    '{{WRAPPER}} .modern-postby li:hover .content-of-post-list h2' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'post_count',
            [
                'label' => __( 'How many blog post', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => __( '5', 'wpsmart-elementor-plugin' ),
                'max' => 8,
            ]
        );

        $this->add_control(
            'cat_type',
            [
                'label' => __( 'Select Category', 'essential-addons-elementor' ),
                'type' => Controls_Manager::SELECT,
                'options' => wpsmart_post_type_categories(),
                'default' => 'post',

            ]
        );

        $this->add_control(
            'show_first_tag',
            [
                'label' => __( 'Show First Tag', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Hide', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'width
            ',
            [
                'label' => __( 'First Post Font Size', 'wpsmart-elementor-plugin' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 14,
                        'max' => 60,
                        'step' => 5,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 40,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 14,
                ],
                'selectors' => [
                    '{{WRAPPER}} .modern-postby .widget-start .other-post-list ul .first-post .cover-content .wp-content-area h2' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'show_posted_date',
            [
                'label' => __( 'Show Post Date', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Hide', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'show_hide_comment_count',
            [
                'label' => __( 'Show Comment Count Date', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Hide', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

		$this->end_controls_section();

		//Style Section
		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Style', 'wpsmart-elementor-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);


        $this->add_control(
            'verticle_only_post',
            [
                'label' => __( 'Vertical Post Only', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'On', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Off', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );


        $this->add_control(
            'box-style-enable',
            [
                'label' => __( 'Card Style Enable', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Enable', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Disable', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

        $this->add_control(
            'dark_theme_active',
            [
                'label' => __( 'Dark Theme Activate Enable', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Enable', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Disable', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

		$this->end_controls_section();
	}

	protected function render( $instance = [] ) {
		$settings = $this->get_settings_for_display();
        ?>
        <div class="modern-postby <?php if ( 'yes' === $settings['box-style-enable'] ) { ?> card-design <?php } ?>">
            <?php   if ($settings['widget_title']) { ?>
                <div class="widget-title-section <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>">
                <div class="titles-pack">
                    <?php if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) { ?>
                        <h2 class="main-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>"><?php echo $settings['widget_title'] ?>
                            <span class="bottom-border"></span>
                        </h2>
                        <span class="sub-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>"><?php echo $settings['widget_sub_title'] ?></span>
                    <?php } else {?>
                        <h2 class="main-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>" style="color: <?php echo $settings['title_color']; ?>;">
                            <?php echo $settings['widget_title'] ?>
                            <span class="bottom-border" style="background: <?php echo $settings['title_border_color']; ?>;"></span>
                        </h2>
                        <span class="sub-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>" style="color: <?php echo $settings['sub_title_color']; ?>;"><?php echo $settings['widget_sub_title'] ?></span>
                    <?php } ?>
                </div>
                <div class="title-options">
                    <a href="<?php echo get_category_link( $settings['cat_type'] ); ?>" class="more <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>"><?php echo esc_attr_e( 'More', 'siren' ); ?></a>
                </div>
            </div>
            <?php } ?>
            <div class="widget-start">
                <div class="other-post-list">
                    <ul>
            <?php
                global $post;
                $count = 0;
                $magaz_header = get_posts( array(
                    'posts_per_page' => $settings['post_count'],
                    'category'       => $settings['cat_type'],
                ) );
                    if ( $magaz_header ) {
                        foreach ( $magaz_header as $post ) : setup_postdata( $post ); ?>
                            <?php $count++; ?>
                            <?php if ($count == 1) : ?>
                            <li class="first-post <?php if ( 'yes' === $settings['verticle_only_post'] ) { ?> vticle-on-off <?php } ?>">
                                <div class="cover-content" <?php if ( 'no' === $settings['verticle_only_post'] ) { ?> style="max-height: calc(105px * ( <?php echo $settings['post_count']?> - 1) - 0px)" <?php } ?>>
                                    <?php if ( 'yes' === $settings['show_first_tag'] ) {
                                        $post_tags = get_the_tags();
                                        $mysettings = get_term_meta( $post_tags[0]->term_id, 'custom_taxonomy_options', true );
                                        if ($post_tags) { ?>
                                            <div class="block-tag" <?php if (!empty($mysettings['custom_tag_color'])) { ?> style="background: <?php echo $mysettings['custom_tag_color']; ?>; color: <?php echo $mysettings['custom_tag_font_color']; ?>;" <?php } ?>>
                                                <?php
                                                $string = $post_tags[0]->name;
                                                $firstCharacter = mb_substr($string,0,1,'utf-8');
                                                echo _($firstCharacter);
                                                ?>
                                            </div>
                                            <span class="tag-simple">
                                            <?php
                                            echo $post_tags[0]->name;
                                            ?>
                                            </span>
                                    <?php } } ?>
                                    <?php if ( has_post_format( 'video' )) { ?>
                                        <i class="post-by-type fas fa-video"></i>
                                    <?php } else if ( has_post_format( 'gallery' )) { ?>
                                        <i class="post-by-type fas fa-images"></i>
                                    <?php } else if ( has_post_format( 'quote' )) { ?>
                                        <i class="post-by-type fas fa-quote-right"></i>
                                    <?php } else if ( has_post_format( 'audio' )) { ?>
                                        <i class="post-by-type fab fa-itunes-note"></i>
                                    <?php }?>
                                    <div class="full-preview">
                                    <span class="open-newtab">
                                        <a href="<?php the_permalink(); ?>" target="_blank">
                                            <i class="fas fa-external-link-alt"></i>
                                        </a>
                                    </span>
                                        <?php if ( has_post_thumbnail() ) { ?>
                                            <span class="preview-image">
                                        <?php $feat_image_url = wp_get_attachment_url( get_post_thumbnail_id() ); ?>
                                                <a href="<?php echo $feat_image_url ?>" class="open-lightbox">
                                            <i class="fas fa-search-plus"></i>
                                        </a>
                                    </span>
                                        <?php } ?>
                                    </div>
                                    <?php
                                    $meta_value = get_post_meta ( get_the_ID(), 'siren_metadata', true );
                                    if ( $meta_value['upload_preview_video'] ) {?>
                                        <video loop autoplay muted>
                                            <source src="<?php echo $meta_value['upload_preview_video']; ?>" type="video/mp4">
                                            <source src="<?php echo $meta_value['upload_preview_video']; ?>" type="video/ogg">
                                        </video>
                                    <?php } else { ?>
                                        <?php the_post_thumbnail('siren-main-post-thumb'); ?>
                                    <?php } ?>
                                    <div class="wp-content-area">
                                        <?php if ( 'yes' === $settings['show_post_view'] ) { ?>
                                        <div class="post-host-counter">
                                            <i class="fab fa-hotjar"></i><?php echo getPostViews(get_the_ID()); ?> Views
                                        </div>
                                        <?php } ?>
                                        <a href="<?php the_permalink(); ?>">
                                            <h2>
                                                <?php the_title(); ?>
                                            </h2>
                                        </a>
                                        <div class="post-contrnt-footer">
                                            <div class="post-time white">
                                                <?php if ( 'yes' === $settings['show_posted_date'] ) { ?>
                                                    <i class="far fa-clock"></i> <?php echo wpsmart_posttime();
                                                } ?>
                                            </div>
                                            <div class="comment-count white">
                                                <?php if ( 'yes' === $settings['show_hide_comment_count'] ) { ?>
                                                    <a href="<?php the_permalink(); ?>">
                                                        <i class="far fa-comment"></i> <?php echo $post->comment_count; ?>
                                                    </a>
                                                <?php } ?>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </li>
                            <?php else : ?>
                            <li class="<?php if ( 'yes' === $settings['verticle_only_post'] ) { ?> vticle-on-off <?php } ?>">
                                <div class="post-list-content tttrrr">
                                    <div class="image-thumbnail-section">
                                        <?php if ( has_post_format( 'video' )) { ?>
                                            <i class="post-by-type fas fa-video"></i>
                                        <?php } else if ( has_post_format( 'gallery' )) { ?>
                                            <i class="post-by-type fas fa-images"></i>
                                        <?php } else if ( has_post_format( 'quote' )) { ?>
                                            <i class="post-by-type fas fa-quote-right"></i>
                                        <?php } else if ( has_post_format( 'audio' )) { ?>
                                            <i class="post-by-type fab fa-itunes-note"></i>
                                        <?php }?>
                                        <div class="popup-andlink">
                                            <?php if ( has_post_thumbnail() ) { ?>
                                                <span class="preview-text">
                                                    <?php $feat_image_url = wp_get_attachment_url( get_post_thumbnail_id() ); ?>
                                                                <a href="<?php echo $feat_image_url ?>" class="open-lightbox">
                                                    <?php echo esc_attr_e( 'Preview', 'siren' ); ?>
                                                    </a>
                                                </span>
                                            <?php } ?>
                                            <div class="main-link">
                                                <a href="<?php the_permalink(); ?>" target="_blank">
                                                    <i class="fas fa-external-link-alt"></i>
                                                </a>
                                            </div>
                                        </div>
                                        <?php the_post_thumbnail('siren-extra-small-post-thumb'); ?>
                                        <div class="share-buttons-home small-share">
                                            <a target="_blank" class="fb-share" href="https://www.facebook.com/sharer/sharer.php?u=<?php the_permalink(); ?>">
                                                <i class="fab fa-facebook-f"></i>
                                            </a>
                                            <a target="_blank" href="//pinterest.com/pin/create/link/?url=<?php the_permalink();?>&amp;description=<?php $shareblettl =  get_the_title(); echo str_replace(" ", "%20", $shareblettl); ?>" class="pin-share">
                                                <i class="fab fa-pinterest-p"></i>
                                            </a>
                                            <a target="_blank" href="https://twitter.com/intent/tweet?url=<?php the_permalink(); ?>&text=<?php $shareblettl =  get_the_title(); echo str_replace(" ", "%20", $shareblettl); ?>" class="tw-share">
                                                <i class="fab fa-twitter"></i>
                                            </a>
                                        </div>
                                    </div>
                                    <div class="content-of-post-list">
                                        <?php if ( 'yes' === $settings['show_first_tag'] ) {
                                            $post_tags = get_the_tags();
                                            $mysettings = get_term_meta( $post_tags[0]->term_id, 'custom_taxonomy_options', true );
                                            if ($post_tags) { ?>
                                                <span class="small-post-tag-x" <?php if (!empty($mysettings['custom_tag_color'])) { ?> style="background: <?php echo $mysettings['custom_tag_color']; ?>; color: <?php echo $mysettings['custom_tag_font_color']; ?>;" <?php } ?>>
                                                     <?php
                                                     $string = $post_tags[0]->name;
                                                     $firstCharacter = mb_substr($string,0,1,'utf-8');
                                                     echo _($firstCharacter);
                                                     ?>
                                                </span>
                                                <span class="simple-font-x">
                                                     <?php
                                                     echo $post_tags[0]->name;
                                                     ?>
                                                </span>
                                            <?php } } ?>
                                        <a href="<?php the_permalink(); ?>">
                                            <h2 class="<?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>"><?php the_title(); ?></h2>
                                        </a>
                                        <div class="post-meta">
                                            <div class="post-time <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>">
                                                <?php if ( 'yes' === $settings['show_posted_date'] ) { ?> <i class="far fa-clock"></i> <?php echo wpsmart_posttime(); } ?>
                                            </div>
                                            <div class="comment-count <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>">
                                                <?php if ( 'yes' === $settings['show_hide_comment_count'] ) { ?>
                                                    <a href="<?php the_permalink(); ?>">
                                                        <i class="far fa-comment"></i> <?php echo $post->comment_count; ?>
                                                    </a>
                                                <?php } ?>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </li>
                        <?php endif; ?>
                        <?php
                    endforeach;
                        wp_reset_postdata();
                    } ?>
                    </ul>
                </div>
            </div>

        </div>


        <?php
	}

	protected function _content_template() {}

    public function render_plain_content( $instance = [] ) {}
}
