<?php
namespace WpsmartSirenTheme\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Full_page_slider extends Widget_Base {


	public function get_name() {
		return 'full-page-postslider';
	}

	public function get_title() {
		return __( 'Post Slider', 'wpsmart-elementor-plugin' );
	}

	public function get_icon() {
		return 'eicon-slider-video';
	}

	public function get_categories() {
		return [ 'wpsmart-widget' ];
	}

	public function get_script_depends() {
		return [ 'wpsmart-elementor-plugin' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'wpsmart-elementor-plugin' ),
			]
		);

        $this->add_control(
            'widget_title',
            [
                'label' => __( 'Title', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Default title', 'wpsmart-elementor-plugin' ),
                'placeholder' => __( 'Type your title here', 'wpsmart-elementor-plugin' ),
            ]
        );

        $this->add_control(
            'widget_sub_title',
            [
                'label' => __( 'Sub Title', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Default sub title', 'wpsmart-elementor-plugin' ),
                'placeholder' => __( 'Type your sub-title here', 'wpsmart-elementor-plugin' ),
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => __( 'Main Title Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => 'rgba(0, 0, 0, 0.87)',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .widget-title-section .titles-pack .main-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'sub_title_color',
            [
                'label' => __( 'Sub Title Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => 'rgba(0, 0, 0, 0.54)',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .widget-title-section .titles-pack .sub-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'title_border_color',
            [
                'label' => __( 'Title Bottom Border Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#FC0E0E',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .widget-title-section .titles-pack .main-title .bottom-border' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'unique_widget_id',
            [
                'label' => __( 'Type Unique ID', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'placeholder' => __( 'uniqueid_2545', 'wpsmart-elementor-plugin' ),
                'default' => __( 'default_unique_id_123', 'wpsmart-elementor-plugin' ),
            ]
        );

        $this->add_control(
            'post_count',
            [
                'label' => __( 'How many blog post', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => __( '10', 'wpsmart-elementor-plugin' ),
                'min' => 3,
                'max' => 30,
            ]
        );

        $this->add_control(
            'font_size_slider',
            [
                'label' => __( 'Main Font size', 'wpsmart-elementor-plugin' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 14,
                        'max' => 60,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 40,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 14,
                ],
                'selectors' => [
                    '{{WRAPPER}} .full-page-slider .content-slider-page .owl-carousel .image-slider-full-cap .slider-content h2' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'height_of_images',
            [
                'label' => __( 'Change Slider Height', 'wpsmart-elementor-plugin' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ '%' ],
                'range' => [
                    'px' => [
                        'min' => 20,
                        'max' => 500,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 20,
                        'max' => 500,
                        'step' => 1,
                    ],
                ],
                'default' => [
                    'unit' => '%',
                    'size' => 56,
                ],
                'selectors' => [
                    '{{WRAPPER}} .full-page-slider .content-slider-page .owl-carousel .image-slider-full-cap .height-of-content' => 'padding-top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'cat_type',
            [
                'label' => __( 'Select Category', 'essential-addons-elementor' ),
                'type' => Controls_Manager::SELECT,
                'options' => wpsmart_post_type_categories(),
                'default' => 'post',

            ]
        );

        $this->add_control(
            'show_first_tag',
            [
                'label' => __( 'Show First Tag', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Hide', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'show_post_view',
            [
                'label' => __( 'Show Posted Views', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Hide', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'show_posted_date',
            [
                'label' => __( 'Show Posted Date', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Hide', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'Show_hide_comment_count',
            [
                'label' => __( 'Show Comment Count Date', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Hide', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

		$this->end_controls_section();

        //Style Section
        $this->start_controls_section(
            'section_style',
            [
                'label' => __( 'Style', 'wpsmart-elementor-plugin' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'white_bg_slider',
            [
                'label' => __( 'Active Slider Style 2', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'On', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Off', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );


        $this->add_control(
            'box-style-enable',
            [
                'label' => __( 'Card Style Enable', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Enable', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Disable', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

        $this->add_control(
            'dark_theme_active',
            [
                'label' => __( 'Dark Theme Activate Enable', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Enable', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Disable', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

        $this->end_controls_section();

	}

	protected function render( $instance = [] ) {
		$settings = $this->get_settings_for_display();

        ?>
        <div class="full-page-slider <?php if ( 'yes' === $settings['box-style-enable'] ) { ?> card-design <?php } ?>">
            <?php   if ($settings['widget_title']) { ?>
            <div class="widget-title-section <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>">
                <div class="titles-pack">
                    <?php if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) { ?>
                        <h2 class="main-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>"><?php echo $settings['widget_title'] ?>
                            <span class="bottom-border"></span>
                        </h2>
                        <span class="sub-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>"><?php echo $settings['widget_sub_title'] ?></span>
                    <?php } else {?>
                        <h2 class="main-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>" style="color: <?php echo $settings['title_color']; ?>;">
                            <?php echo $settings['widget_title'] ?>
                            <span class="bottom-border" style="background: <?php echo $settings['title_border_color']; ?>;"></span>
                        </h2>
                        <span class="sub-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>" style="color: <?php echo $settings['sub_title_color']; ?>;"><?php echo $settings['widget_sub_title'] ?></span>
                    <?php } ?>
                </div>
                <div class="title-options">
                    <div id="wpsmart-<?php echo $settings['unique_widget_id']?>" class="carousel-dots">
                    </div>
                </div>
            </div>
            <?php } ?>
            <?php if ( 'yes' === $settings['white_bg_slider'] ) { ?>
                <div class="content-slider-page">
                    <div class="arrow-sliders">
                        <div class="arrow-size right_arrow" id="<?php echo $settings['unique_widget_id']?>next"><i class="fa fa-chevron-right" aria-hidden="true"></i></div>
                        <div class="arrow-size left_arrow" id="<?php echo $settings['unique_widget_id']?>prev"><i class="fa fa-chevron-left" aria-hidden="true"></i></div>
                    </div>
                    <div id="<?php echo $settings['unique_widget_id']?>" class="owl-carousel owl-theme">
                        <?php
                        global $post;
                        $magaz_header = get_posts( array(
                            'posts_per_page' => 4,
                            'category'       => $settings['cat_type']
                        ) );
                        if ( $magaz_header ) {
                            foreach ( $magaz_header as $post ) :
                                setup_postdata( $post ); ?>
                                <div class="item">
                                    <div class="image-slider-full-cap">
                                        <div class="height-of-content"></div>
                                        <?php if ( 'yes' === $settings['show_first_tag'] ) {
                                            $post_tags = get_the_tags();
                                            $mysettings = get_term_meta( $post_tags[0]->term_id, 'custom_taxonomy_options', true );
                                            if ($post_tags) { ?>
                                                <div class="block-tag" <?php if (!empty($mysettings['custom_tag_color'])) { ?> style="background: <?php echo $mysettings['custom_tag_color']; ?>; color: <?php echo $mysettings['custom_tag_font_color']; ?>;" <?php } ?>>
                                                    <?php
                                                    $string = $post_tags[0]->name;
                                                    $firstCharacter = mb_substr($string,0,1,'utf-8');
                                                    echo _($firstCharacter);
                                                    ?>
                                                </div>
                                                <span class="tag-simple">
                                            <?php
                                            echo $post_tags[0]->name;
                                            ?>
                                            </span>
                                            <?php } } ?>
                                        <?php if ( has_post_format( 'video' )) { ?>
                                            <i class="post-by-type fas fa-video"></i>
                                        <?php } else if ( has_post_format( 'gallery' )) { ?>
                                            <i class="post-by-type fas fa-images"></i>
                                        <?php } else if ( has_post_format( 'quote' )) { ?>
                                            <i class="post-by-type fas fa-quote-right"></i>
                                        <?php } else if ( has_post_format( 'audio' )) { ?>
                                            <i class="post-by-type fab fa-itunes-note"></i>
                                        <?php }?>
                                        <?php the_post_thumbnail('siren-main-post-thumb'); ?>
                                        <div class="slider-content whitebg-on">
                                            <?php if ( 'yes' === $settings['show_post_view'] ) { ?>
                                                <div class="post-host-counter">
                                                    <i class="fab fa-hotjar"></i><?php echo getPostViews(get_the_ID()); ?> Views
                                                </div>
                                            <?php } ?>
                                            <a href="<?php the_permalink(); ?>">
                                                <h2><?php the_title(); ?></h2>
                                            </a>
                                            <div class="slider-meta">
                                                <div class="post-contrnt-footer">
                                                    <div class="post-time white">
                                                        <i class="far fa-clock"></i> <?php if ( 'yes' === $settings['show_posted_date'] ) { echo wpsmart_posttime(); } ?>
                                                    </div>
                                                    <div class="comment-count white">
                                                        <a href="<?php the_permalink(); ?>">
                                                            <i class="far fa-comment"></i> <?php echo $post->comment_count; ?>
                                                        </a>
                                                    </div>
                                                </div>
                                            </div>
                                            <div class="post-content">
                                                <p>
                                                    <?php echo wp_trim_words( get_the_content(), 30, '...' ); ?>
                                                </p>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            <?php endforeach; wp_reset_postdata(); } ?>
                    </div>
                </div>
            <?php } else { ?>
                <div class="content-slider-page">
                    <div id="<?php echo $settings['unique_widget_id']?>" class="owl-carousel owl-theme">
                        <?php
                        global $post;

                        $magaz_header = get_posts( array(
                            'posts_per_page' => 4,
                            'category'       => $settings['cat_type']
                        ) );
                        if ( $magaz_header ) {
                            foreach ( $magaz_header as $post ) :
                                setup_postdata( $post ); ?>
                                <div class="item">
                                    <div class="image-slider-full-cap">
                                        <div class="height-of-content"></div>
                                        <?php if ( 'yes' === $settings['show_first_tag'] ) {
                                            $post_tags = get_the_tags();
                                            $mysettings = get_term_meta( $post_tags[0]->term_id, 'custom_taxonomy_options', true );
                                            if ($post_tags) { ?>
                                                <div class="block-tag" <?php if (!empty($mysettings['custom_tag_color'])) { ?> style="background: <?php echo $mysettings['custom_tag_color']; ?>; color: <?php echo $mysettings['custom_tag_font_color']; ?>;" <?php } ?>>
                                                    <?php
                                                    $string = $post_tags[0]->name;
                                                    $firstCharacter = mb_substr($string,0,1,'utf-8');
                                                    echo _($firstCharacter);
                                                    ?>
                                                </div>
                                                <span class="tag-simple">
                                            <?php
                                            echo $post_tags[0]->name;
                                            ?>
                                            </span>
                                            <?php } } ?>
                                        <div class="right-top-post-type">
                                            <?php if ( has_post_format( 'video' )) { ?>
                                                <i class="post-by-type fas fa-video"></i>
                                            <?php } else if ( has_post_format( 'gallery' )) { ?>
                                                <i class="post-by-type fas fa-images"></i>
                                            <?php } else if ( has_post_format( 'quote' )) { ?>
                                                <i class="post-by-type fas fa-quote-right"></i>
                                            <?php } else if ( has_post_format( 'audio' )) { ?>
                                                <i class="post-by-type fab fa-itunes-note"></i>
                                            <?php }?>
                                        </div>
                                        <?php the_post_thumbnail('siren-main-post-thumb'); ?>
                                        <div class="slider-content">
                                            <?php if ( 'yes' === $settings['show_post_view'] ) { ?>
                                                <div class="post-host-counter">
                                                    <i class="fab fa-hotjar"></i><?php echo getPostViews(get_the_ID()); ?> Views
                                                </div>
                                            <?php } ?>
                                            <a href="<?php the_permalink(); ?>">
                                                <h2><?php the_title(); ?></h2>
                                            </a>
                                            <div class="slider-meta">
                                                <div class="post-contrnt-footer">
                                                    <div class="post-time white">
                                                        <i class="far fa-clock"></i> <?php if ( 'yes' === $settings['show_posted_date'] ) { echo wpsmart_posttime(); } ?>
                                                    </div>
                                                    <div class="comment-count white">
                                                        <a href="<?php the_permalink(); ?>">
                                                            <i class="far fa-comment"></i> <?php echo $post->comment_count; ?>
                                                        </a>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            <?php endforeach; wp_reset_postdata(); } ?>
                    </div>
                </div>
            <?php } ?>
        </div>

        <?php if ( 'yes' === $settings['white_bg_slider'] ) { ?>

             <script>
                 jQuery( document ).ready( function( $ ) {
                     $('#<?php echo $settings['unique_widget_id']?>').owlCarousel({
                         loop:false,
                         nav: false,
                         animateOut: 'fadeOut',
                         dots: true,
                         dotsContainer: '#wpsmart-<?php echo $settings['unique_widget_id']?>',
                         autoplay: false,
                         responsive:{
                             0:{
                                 items:1
                             },
                             600:{
                                 items:1
                             },
                             1000:{
                                 items:1
                             }
                         }
                     });

                     <?php echo $settings['unique_widget_id']?> = $('#<?php echo $settings['unique_widget_id']?>.owl-carousel').owlCarousel();
                     $("#<?php echo $settings['unique_widget_id']?>prev").click(function () {
                         <?php echo $settings['unique_widget_id']?>.trigger('prev.owl.carousel');
                     });

                     $("#<?php echo $settings['unique_widget_id']?>next").click(function () {
                         <?php echo $settings['unique_widget_id']?>.trigger('next.owl.carousel');
                     });
                 } );
             </script>

        <?php } else { ?>

            <script>

                jQuery( document ).ready( function( $ ) {
                    $('#<?php echo $settings['unique_widget_id']?>').owlCarousel({
                        loop:true,
                        nav: false,
                        dots: false,
                        responsive:{
                            0:{
                                items:1
                            },
                            600:{
                                items:1
                            },
                            1000:{
                                items:1
                            }
                        }
                    });
                } );
            </script>

        <?php } ?>



        <?php }

	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _content_template() {}

    public function render_plain_content( $instance = [] ) {}
}
