<?php
namespace WpsmartSirenTheme\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Gallery_block extends Widget_Base {

	public function get_name() {
		return 'Large-gallery-block';
	}

	public function get_title() {
		return __( 'Post Slider', 'wpsmart-elementor-plugin' );
	}

	public function get_icon() {
		return 'eicon-gallery-grid';
	}

	public function get_categories() {
		return [ 'wpsmart-widget' ];
	}


	public function get_script_depends() {
		return [ 'wpsmart-elementor-plugin' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'wpsmart-elementor-plugin' ),
			]
		);

        $this->add_control(
            'widget_title',
            [
                'label' => __( 'Title', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Default title', 'wpsmart-elementor-plugin' ),
                'placeholder' => __( 'Type your title here', 'wpsmart-elementor-plugin' ),
            ]
        );

        $this->add_control(
            'widget_sub_title',
            [
                'label' => __( 'Sub Title', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Default sub title', 'wpsmart-elementor-plugin' ),
                'placeholder' => __( 'Type your sub-title here', 'wpsmart-elementor-plugin' ),
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => __( 'Main Title Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => 'rgba(0, 0, 0, 0.87)',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .widget-title-section .titles-pack .main-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'sub_title_color',
            [
                'label' => __( 'Sub Title Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => 'rgba(0, 0, 0, 0.54)',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .widget-title-section .titles-pack .sub-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'title_border_color',
            [
                'label' => __( 'Title Bottom Border Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#FC0E0E',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .widget-title-section .titles-pack .main-title .bottom-border' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'unique_widget_id',
            [
                'label' => __( 'Type Unique ID', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'placeholder' => __( 'uniqueid_2545', 'wpsmart-elementor-plugin' ),
                'default' => __( 'cor_slide_unique_id_9859', 'wpsmart-elementor-plugin' ),
            ]
        );

        $this->add_control(
            'post_count',
            [
                'label' => __( 'How many blog post', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => __( '10', 'wpsmart-elementor-plugin' ),
                'min' => 1,
                'max' => 30,
            ]
        );

        $this->add_control(
            'cat_type',
            [
                'label' => __( 'Select Category', 'essential-addons-elementor' ),
                'type' => Controls_Manager::SELECT,
                'options' => wpsmart_post_type_categories(),
                'default' => 'post',

            ]
        );

        $this->add_control(
            'show_first_tag',
            [
                'label' => __( 'Show First Tag', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Hide', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'show_posted_date',
            [
                'label' => __( 'Show Posted Date', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Hide', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'Show_hide_comment_count',
            [
                'label' => __( 'Show/Hide Comment Count Date', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Hide', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'Show_hide_post_content',
            [
                'label' => __( 'Show/Hide Post Content', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Hide', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

		$this->end_controls_section();

		//Style Section
		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Style', 'wpsmart-elementor-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

        $this->add_control(
            'post_view_count_desktop',
            [
                'label' => __( 'Post Per Desktop View', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => __( '4', 'wpsmart-elementor-plugin' ),
                'min' => 2,
                'max' => 6,
            ]
        );


        $this->add_control(
            'post_view_count_tablet',
            [
                'label' => __( 'Post Per Tablet View', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => __( '2', 'wpsmart-elementor-plugin' ),
                'min' => 2,
                'max' => 4,
            ]
        );


        $this->add_control(
            'post_view_count_mobile',
            [
                'label' => __( 'Post Per Mobile View', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => __( '1', 'wpsmart-elementor-plugin' ),
                'min' => 1,
                'max' => 3,
            ]
        );

        $this->add_control(
            'dark_theme_active',
            [
                'label' => __( 'Dark Theme Activate Enable', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Enable', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Disable', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

		$this->end_controls_section();
	}

	protected function render( $instance = [] ) {
		$settings = $this->get_settings_for_display();

        ?>
        <div class="full-gallery">
            <?php   if ($settings['widget_title']) { ?>
            <div class="widget-title-section <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>">
                <div class="titles-pack">
                    <?php if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) { ?>
                        <h2 class="main-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>"><?php echo $settings['widget_title'] ?>
                            <span class="bottom-border"></span>
                        </h2>
                        <span class="sub-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>"><?php echo $settings['widget_sub_title'] ?></span>
                    <?php } else {?>
                        <h2 class="main-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>" style="color: <?php echo $settings['title_color']; ?>;">
                            <?php echo $settings['widget_title'] ?>
                            <span class="bottom-border" style="background: <?php echo $settings['title_border_color']; ?>;"></span>
                        </h2>
                        <span class="sub-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>" style="color: <?php echo $settings['sub_title_color']; ?>;"><?php echo $settings['widget_sub_title'] ?></span>
                    <?php } ?>
                </div>
                <div class="title-options">
                    <div class="carousel-navi <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>">
                        <div class="right_arrow" id="<?php echo $settings['unique_widget_id']?>next"><i class="fa fa-chevron-right" aria-hidden="true"></i></div>
                        <div class="left_arrow" id="<?php echo $settings['unique_widget_id']?>prev"><i class="fa fa-chevron-left" aria-hidden="true"></i></div>
                    </div>
                </div>
            </div>
            <?php } ?>
            <div id="<?php echo $settings['unique_widget_id']?>" class="owl-carousel owl-theme gallery-post">
                <?php
            global $post;

            $magaz_header = get_posts( array(
                'posts_per_page' => $settings['post_count'],
                'category'       => $settings['cat_type']
            ) );
                if ( $magaz_header ) {
                    foreach ( $magaz_header as $post ) :
                        setup_postdata( $post ); ?>
                        <div class="item">
                            <div class="full-gallery-post">
                                <div class="top-content">
                                    <?php if ( 'yes' === $settings['show_first_tag'] ) {
                                        $post_tags = get_the_tags();
                                        $mysettings = get_term_meta( $post_tags[0]->term_id, 'custom_taxonomy_options', true );
                                        if ($post_tags) { ?>
                                            <span class="rantagred" <?php if (!empty($mysettings['custom_tag_color'])) { ?> style="background: <?php echo $mysettings['custom_tag_color']; ?>; color: <?php echo $mysettings['custom_tag_font_color']; ?>;" <?php } ?>>
                                                <?php
                                                echo $post_tags[0]->name;
                                                ?>
                                            </span>
                                        <?php } } ?>
                                    <?php the_post_thumbnail('siren-extra-small-post-thumb'); ?>
                                </div>
                                <div class="post-content">
                                    <a href="<?php the_permalink(); ?>">
                                        <h2 class="<?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>"><?php the_title(); ?></h2>
                                    </a>
                                    <div class="post-meta">
                                        <div class="post-time <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>">
                                            <?php if ( 'yes' === $settings['show_posted_date'] ) { ?> <i class="far fa-clock"></i> <?php echo wpsmart_posttime(); } ?>
                                        </div>
                                        <?php  if ( 'yes' === $settings['Show_hide_comment_count'] ) { ?>
                                            <div class="comment-count <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>">
                                                <a href="<?php the_permalink(); ?>">
                                                    <i class="far fa-comment"></i> <?php echo $post->comment_count; ?>
                                                </a>
                                            </div>
                                        <?php } ?>
                                    </div>
                                    <p class="extended-text <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>">
                                        <?php  if ( 'yes' === $settings['Show_hide_post_content'] ) { ?>
                                        <?php echo wp_trim_words( get_the_content(), 6, '...' ); ?>
                                        <?php } ?>
                                    </p>
                                </div>
                            </div>
                        </div>
                <?php
                    endforeach;
                        wp_reset_postdata();
                } ?>
            </div>

        </div>

        <script>
            jQuery( document ).ready( function( $ ) {
                //Slider Post
                $('#<?php echo $settings['unique_widget_id']?>').owlCarousel({
                    margin:20,
                    nav: false,
                    dots: true,
                    dotsContainer: '#wpsmart-<?php echo $settings['unique_widget_id']?>',
                    responsive:{
                        0:{items:<?php echo $settings['post_view_count_mobile']?>},
                        600:{items:<?php echo $settings['post_view_count_tablet']?>},
                        1000:{items:<?php echo $settings['post_view_count_desktop']?>}
                    }
                });

                <?php echo $settings['unique_widget_id']?> = $('#<?php echo $settings['unique_widget_id']?>.owl-carousel').owlCarousel();
                $("#<?php echo $settings['unique_widget_id']?>prev").click(function () {
                    <?php echo $settings['unique_widget_id']?>.trigger('prev.owl.carousel');
                });

                $("#<?php echo $settings['unique_widget_id']?>next").click(function () {
                    <?php echo $settings['unique_widget_id']?>.trigger('next.owl.carousel');
                });

            } );
        </script>

        <?php
	}

	protected function _content_template() {}

    public function render_plain_content( $instance = [] ) {}
}
