<?php
namespace WpsmartSirenTheme\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Grid_post_list extends Widget_Base {

	public function get_name() {
		return 'grid-post-list';
	}

	public function get_title() {
		return __( 'Simple Grid', 'wpsmart-elementor-plugin' );
	}

	public function get_icon() {
		return 'eicon-gallery-group';
	}

	public function get_categories() {
		return [ 'wpsmart-widget' ];
	}

	public function get_script_depends() {
		return [ 'wpsmart-elementor-plugin' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'wpsmart-elementor-plugin' ),
			]
		);

        $this->add_control(
            'content_height',
            [
                'label' => __( 'Block Height', 'wpsmart-elementor-plugin' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ '%' ],
                'range' => [
                    'px' => [
                        'min' => 20,
                        'max' => 500,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 20,
                        'max' => 500,
                        'step' => 1,
                    ],
                ],
                'default' => [
                    'unit' => '%',
                    'size' => 65,
                ],
                'selectors' => [
                    '{{WRAPPER}} .right-side-post .right-side-content .right-post-section:before' => 'padding-top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'unique_widget_id',
            [
                'label' => __( 'Type Unique ID', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'placeholder' => __( 'uniqueid_2545', 'wpsmart-elementor-plugin' ),
                'default' => __( 'unique_magazine_head_123', 'wpsmart-elementor-plugin' ),
            ]
        );

        $this->add_control(
            'post_per_magazine',
            [
                'label' => __( 'Post Per Set', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'min' => 2,
                'max' => 5,
                'default' => 5,
            ]
        );

        $this->add_control(
            'cat_type_two',
            [
                'label' => __( 'Select Category', 'essential-addons-elementor' ),
                'type' => Controls_Manager::SELECT,
                'options' => wpsmart_post_type_categories(),
                'default' => 'post',

            ]
        );

        $this->add_control(
            'show_first_tag',
            [
                'label' => __( 'Show First Tag', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Hide', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'show_posted_date',
            [
                'label' => __( 'Show Posted Date', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Hide', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'Show_hide_comment_count',
            [
                'label' => __( 'Show Comment Count Date', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Hide', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

		$this->end_controls_section();

	}

	protected function render( $instance = [] ) {
		$settings = $this->get_settings_for_display();

        ?>
        <div class="right-side-post">
            <?php
            global $post;
            $magaz_header = get_posts( array(
                'posts_per_page' => $settings['post_per_magazine'],
                'category'       => $settings['cat_type_two']
            ) );
            ?>
            <div class="right-side-content">
                <?php
                if ( $magaz_header ) {
                    foreach ( $magaz_header as $post ) :
                        setup_postdata( $post ); ?>
                        <div class="right-post-section">
                            <?php if ( 'yes' === $settings['show_first_tag'] ) {
                                $post_tags = get_the_tags();
                                $mysettings = get_term_meta( $post_tags[0]->term_id, 'custom_taxonomy_options', true );
                                if ($post_tags) { ?>
                                    <div class="block-tag" <?php if (!empty($mysettings['custom_tag_color'])) { ?> style="background: <?php echo $mysettings['custom_tag_color']; ?>; color: <?php echo $mysettings['custom_tag_font_color']; ?>;" <?php } ?>>
                                        <?php
                                        $string = $post_tags[0]->name;
                                        $firstCharacter = mb_substr($string,0,1,'utf-8');
                                        echo _($firstCharacter);
                                        ?>
                                    </div>
                                    <span class="tag-simple">
                                    <?php
                                    echo $post_tags[0]->name;
                                    ?>
                                </span>
                                <?php } } ?>
                            <?php if ( has_post_format( 'video' )) { ?>
                                <i class="post-by-type fas fa-video"></i>
                            <?php } else if ( has_post_format( 'gallery' )) { ?>
                                <i class="post-by-type fas fa-images"></i>
                            <?php } else if ( has_post_format( 'quote' )) { ?>
                                <i class="post-by-type fas fa-quote-right"></i>
                            <?php } else if ( has_post_format( 'audio' )) { ?>
                                <i class="post-by-type fab fa-itunes-note"></i>
                            <?php }?>
                            <?php the_post_thumbnail('siren-main-post-thumb'); ?>
                            <div class="wp-content-area">
                                <div class="post-host-counter">
                                    <i class="fab fa-hotjar"></i><?php echo getPostViews(get_the_ID()); ?>
                                </div>
                                <a href="<?php the_permalink(); ?>">
                                    <h2><?php the_title(); ?></h2>
                                </a>
                                <div class="post-contrnt-footer">
                                    <div class="post-time white">
                                        <?php if ( 'yes' === $settings['show_posted_date'] ) { ?>
                                            <i class="far fa-clock"></i> <?php echo wpsmart_posttime(); } ?>
                                    </div>
                                    <?php  if ( 'yes' === $settings['Show_hide_comment_count'] ) { ?>
                                        <div class="comment-count white">
                                            <a href="<?php the_permalink(); ?>">
                                                <i class="far fa-comment"></i> <?php echo $post->comment_count; ?>
                                            </a>
                                        </div>
                                    <?php } ?>
                                </div>
                            </div>
                        </div>
                    <?php
                    endforeach;
                    wp_reset_postdata();
                } ?>
            </div>
        </div>

        <?php
	}

	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _content_template() {}

    public function render_plain_content( $instance = [] ) {}
}
