<?php
namespace WpsmartSirenTheme\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Magazine_home_header extends Widget_Base {

	public function get_name() {
		return 'header--magazine-post';
	}

	public function get_title() {
		return __( 'Magazine Post', 'wpsmart-elementor-plugin' );
	}

	public function get_icon() {
		return 'eicon-gallery-group';
	}

	public function get_categories() {
		return [ 'wpsmart-widget' ];
	}

	public function get_script_depends() {
		return [ 'wpsmart-elementor-plugin' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'wpsmart-elementor-plugin' ),
			]
		);

        $this->add_control(
            'post_per_magazine',
            [
                'label' => __( 'Post Per Set', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'min' => 2,
                'max' => 5,
                'default' => 5,
            ]
        );

        $this->add_control(
            'magazine_style',
            [
                'label' => __( 'Select Post style', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'blog_post_with_three',
                'options' => [
                    'blog_post_with_three'  => __( '4 Blog post with 3 Sizes', 'wpsmart-elementor-plugin' ),
                    'blog_post_with_2' => __( '5 Blog post with 2 Sizes', 'wpsmart-elementor-plugin' ),
                    'blog_post_with_mid_large' => __( '5 Post With Middle Large post', 'wpsmart-elementor-plugin' ),
                ],
            ]
        );

        $this->add_control(
            'cat_type',
            [
                'label' => __( 'Select Category', 'essential-addons-elementor' ),
                'type' => Controls_Manager::SELECT,
                'options' => wpsmart_post_type_categories(),
                'default' => 'post',

            ]
        );

        $this->add_control(
            'show_first_tag',
            [
                'label' => __( 'Show First Tag', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Hide', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'show_posted_date',
            [
                'label' => __( 'Show Posted Date', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Hide', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'Show_hide_comment_count',
            [
                'label' => __( 'Show Comment Count Date', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Hide', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

		$this->end_controls_section();

	}

	protected function render( $instance = [] ) {
		$settings = $this->get_settings_for_display();

        ?>
        <?php if ( 'blog_post_with_three' === $settings['magazine_style'] ) { ?>
        <div class="header-magazin">
            <?php
            global $post;
            $magaz_header = get_posts( array(
                'posts_per_page' => 4,
                'category'       => $settings['cat_type']
            ) );
            ?>
        <?php } else if ( 'blog_post_with_2' === $settings['magazine_style'] ) { ?>
        <div class="five-post-ready">
            <?php
            global $post;
            $magaz_header = get_posts( array(
                'posts_per_page' => 5,
                'category'       => $settings['cat_type']
            ) );
            ?>
        <?php } else if ( 'blog_post_with_mid_large' === $settings['magazine_style'] ) { ?>
            <div class="mid-large-post">
            <?php
            global $post;
            $magaz_header = get_posts( array(
                'posts_per_page' => 5,
                'category'       => $settings['cat_type']
            ) );
            ?>
        <?php } ?>
            <ul>
            <?php


            if ( $magaz_header ) {
                foreach ( $magaz_header as $post ) :
                    setup_postdata( $post ); ?>
                    <li>
                        <?php if ( 'yes' === $settings['show_first_tag'] ) {
                            $post_tags = get_the_tags();
                            $mysettings = get_term_meta( $post_tags[0]->term_id, 'custom_taxonomy_options', true );
                            if ($post_tags) { ?>
                                <div class="block-tag" <?php if (!empty($mysettings['custom_tag_color'])) { ?> style="background: <?php echo $mysettings['custom_tag_color']; ?>; color: <?php echo $mysettings['custom_tag_font_color']; ?>;" <?php } ?>>
                                    <?php
                                    $string = $post_tags[0]->name;
                                    $firstCharacter = mb_substr($string,0,1,'utf-8');
                                    echo _($firstCharacter);
                                    ?>
                                </div>
                                <span class="tag-simple">
                                    <?php
                                    echo $post_tags[0]->name;
                                    ?>
                                </span>
                            <?php } } ?>
                        <?php if ( has_post_format( 'video' )) { ?>
                            <i class="post-by-type fas fa-video"></i>
                        <?php } else if ( has_post_format( 'gallery' )) { ?>
                            <i class="post-by-type fas fa-images"></i>
                        <?php } else if ( has_post_format( 'quote' )) { ?>
                            <i class="post-by-type fas fa-quote-right"></i>
                        <?php } else if ( has_post_format( 'audio' )) { ?>
                            <i class="post-by-type fab fa-itunes-note"></i>
                        <?php }?>
                        <?php the_post_thumbnail('siren-main-post-thumb'); ?>
                        <div class="wp-content-area">
                            <div class="post-host-counter">
                                <i class="fab fa-hotjar"></i><?php echo getPostViews(get_the_ID()); ?>
                            </div>
                            <a href="<?php the_permalink(); ?>">
                                <h2><?php the_title(); ?></h2>
                            </a>
                            <div class="post-contrnt-footer">
                                <div class="post-time white">
                                    <?php if ( 'yes' === $settings['show_posted_date'] ) { ?>
                                        <i class="far fa-clock"></i> <?php echo wpsmart_posttime(); } ?>
                                </div>
                                <?php  if ( 'yes' === $settings['Show_hide_comment_count'] ) { ?>
                                <div class="comment-count white">
                                    <a href="<?php the_permalink(); ?>">
                                        <i class="far fa-comment"></i> <?php echo $post->comment_count; ?>
                                    </a>
                                </div>
                                <?php } ?>
                            </div>
                        </div>
                    </li>


                    <?php
                    endforeach;
                        wp_reset_postdata();
                    } ?>
            </ul>
        </div>
        <?php
	}

	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _content_template() {}

    public function render_plain_content( $instance = [] ) {}
}
