<?php
namespace WpsmartSirenTheme\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Mailchimp_email_widget extends Widget_Base {

	public function get_name() {
		return 'mailchimp_email';
	}

	public function get_title() {
		return __( 'MailChimp Form', 'wpsmart-elementor-plugin' );
	}

	public function get_icon() {
		return 'eicon-email-field';
	}


	public function get_categories() {
		return [ 'wpsmart-widget' ];
	}

	public function get_script_depends() {
		return [ 'wpsmart-elementor-plugin' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'wpsmart-elementor-plugin' ),
			]
		);

        $this->add_control(
            'mailchimp_code',
            [
                'label' => __( 'MailChimp Short Code', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'placeholder' => __( 'Type your title here', 'wpsmart-elementor-plugin' ),
            ]
        );

        $this->add_control(
            'mailchimp_text',
            [
                'label' => __( 'Add Some Text Here', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder' => __( 'Type your title here', 'wpsmart-elementor-plugin' ),
            ]
        );

        $this->add_control(
            'button_color',
            [
                'label' => __( 'Button Text color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#fff',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} input[type=submit]' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'button_bgcolor',
            [
                'label' => __( 'Button Background color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#fc0e0e',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} input[type=submit]' => 'background: {{VALUE}}; border-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'dark_theme_active',
            [
                'label' => __( 'Dark Theme Activate Enable', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Enable', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Disable', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

		$this->end_controls_section();

	}

	protected function render( $instance = [] ) {
		$settings = $this->get_settings_for_display();
		?>

        <div class="email-widget-mchimp <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> dark-mood-active <?php } ?>">
            <i class="fas fa-envelope-open-text"></i>
            <p><?php echo $settings["mailchimp_text"]; ?></p>
            <?php
            $mailchimpa = $settings["mailchimp_code"];
            echo do_shortcode( $mailchimpa );
            ?>
        </div>
        <?php
	}


	protected function _content_template() {}

    public function render_plain_content( $instance = [] ) {}
}
