<?php
namespace WpsmartSirenTheme\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class New_ticker_slide extends Widget_Base {

    
	public function get_name() {
		return 'wpsmart-news-ticer-plugin';
	}

	public function get_title() {
		return __( 'News Ticker', 'wpsmart-elementor-plugin' );
	}

	public function get_icon() {
		return 'eicon-call-to-action';
	}


	public function get_categories() {
		return [ 'wpsmart-widget' ];
	}


	public function get_script_depends() {
		return [ 'wpsmart-elementor-plugin' ];
	}


	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'wpsmart-elementor-plugin' ),
			]
		);

		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'wpsmart-elementor-plugin' ),
				'type' => Controls_Manager::TEXT,
                'default' => 'Hot News',
			]
		);

        $this->add_control(
            'title_bg_color',
            [
                'label' => __( 'Title Background Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#FC0E0E',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .news-ticker .news-head, {{WRAPPER}} .news-ticker .news-head .arrorw-pack' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'icon_color',
            [
                'label' => __( 'Icon Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#fff',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} textxx i' => 'colo: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => __( 'Title Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#ffffff',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .news-ticker .news-head .textxx' => 'color: {{VALUE}}',
                ],
            ]
        );


        $this->add_control(
            'cat_type',
            [
                'label' => __( 'Select Category', 'essential-addons-elementor' ),
                'type' => Controls_Manager::SELECT,
                'options' => wpsmart_post_type_categories(),
                'default' => 'post',
            ]
        );

        $this->add_control(
            'post_count',
            [
                'label' => __( 'How many blog post', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => __( '10', 'wpsmart-elementor-plugin' ),
                'min' => 3,
                'max' => 30,
            ]
        );

        $this->add_control(
            'show_post_thumbnail',
            [
                'label' => __( 'Show Post Thumbnail', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Hide', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'dark_theme_active',
            [
                'label' => __( 'Dark Theme Activate Enable', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Enable', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Disable', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

		$this->end_controls_section();

	}

	protected function render( $instance = [] ) {
		$settings = $this->get_settings_for_display();

        ?>

        <div class="news-ticker <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> dark-mood-active <?php } ?>">
            <?php   if ($settings['title']) { ?>
                <?php if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) { ?>
                <div class="news-head">
                    <span class="textxx"><?php echo $settings['title'] ?></span>
                </div>
                <?php } else {?>
                <div class="news-head" style="background: <?php echo $settings['title_bg_color']?>">
                    <span class="textxx" style="color: <?php echo $settings['title_color']?>">
                        <i style="color: <?php echo $settings['icon_color']?>" class="fa fa-bolt"></i>
                        <?php echo $settings['title'] ?>
                    </span>
                </div>
                <?php } ?>
            <?php } ?>

            <div class="news-content-slider">
                <div class="news-content">
                    <ul id="ticker">
                        <?php
                        global $post;
                        $newsticker = get_posts( array(
                            'posts_per_page' => $settings['post_count'],
                            'category'       => $settings['cat_type']
                        ) );
                            if ( $newsticker ) {
                                foreach ( $newsticker as $post ) :
                                    setup_postdata( $post ); ?>
                        <li>
                            <div class="news-content">
                                <div class="content-of-news">
                                    <a href="<?php the_permalink(); ?>">
                                        <h2><?php the_title(); ?></h2>
                                    </a>
                                    <span class="time-stamp">
                                        <?php echo wpsmart_posttime(); ?>
                                    </span>
                                </div>
                            </div>

                        </li>
                        <?php endforeach; wp_reset_postdata(); } ?>
                    </ul>
                </div>
            </div>
        </div>

        <script>
            jQuery( document ).ready( function( $ ) {

        //News Ticker
        $('#ticker').tickerme({
            fade_speed: 1000,
            auto_stop: false
        });


            } );
        </script>

        <?php
	}

	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _content_template() {}

    public function render_plain_content( $instance = [] ) {}
}
