<?php
namespace WpsmartSirenTheme\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Quotes_slider_widget extends Widget_Base {

	public function get_name() {
		return 'Quotes-full-slider';
	}

	public function get_title() {
		return __( 'Quotes Slider', 'wpsmart-elementor-plugin' );
	}

	public function get_icon() {
		return 'eicon-blockquote';
	}

	public function get_categories() {
		return [ 'wpsmart-widget' ];
	}

	public function get_script_depends() {
		return [ 'wpsmart-elementor-plugin' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'wpsmart-elementor-plugin' ),
			]
		);

        $this->add_control(
            'widget_title',
            [
                'label' => __( 'Title', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Default title', 'wpsmart-elementor-plugin' ),
                'placeholder' => __( 'Type your title here', 'wpsmart-elementor-plugin' ),
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => __( 'Main Title Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#ffffff',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .widget-title-section .titles-pack .main-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'unique_widget_id',
            [
                'label' => __( 'Type Unique ID', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'placeholder' => __( 'uniqueid_2545', 'wpsmart-elementor-plugin' ),
                'default' => __( 'quotes_slider_unique_id_189', 'wpsmart-elementor-plugin' ),
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'list_title', [
                'label' => __( 'Title', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'List Title' , 'wpsmart-elementor-plugin' ),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'list_content', [
                'label' => __( 'Content', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'default' => __( 'List Content' , 'wpsmart-elementor-plugin' ),
                'show_label' => false,
            ]
        );

        $repeater->add_control(
            'list_image', [
                'label' => __( 'Content', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'show_label' => false,
            ]
        );

        $this->add_control(
            'list',
            [
                'label' => __( 'Repeater List', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'list_title' => __( 'Title #1', 'wpsmart-elementor-plugin' ),
                        'list_content' => __( 'Item content. Click the edit button to change this text.', 'wpsmart-elementor-plugin' ),
                        'list_image' => __( '', 'wpsmart-elementor-plugin' ),
                    ],
                    [
                        'list_title' => __( 'Title #2', 'wpsmart-elementor-plugin' ),
                        'list_content' => __( 'Item content. Click the edit button to change this text.', 'wpsmart-elementor-plugin' ),
                        'list_image' => __( '', 'wpsmart-elementor-plugin' ),
                    ],
                ],
                'title_field' => '{{{ list_title }}}',
            ]
        );

		$this->end_controls_section();

	}

	protected function render( $instance = [] ) {
		$settings = $this->get_settings_for_display();

        ?>

        <div class="quate-slider">
            <div class="top-title">
                <?php if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) { ?>
                <h2><?php echo $settings['widget_title'] ?></h2>
                <?php } else {?>
                <h2 style="color: <?php echo $settings['title_color']; ?>;"><?php echo $settings['widget_title'] ?></h2>
                <?php } ?>
                <div class="quates-dots" id="wpsmart-<?php echo $settings['unique_widget_id']?>">
            </div>
            </div>
            <div class="full-slider-qts">
                <div id="<?php echo $settings['unique_widget_id']?>" class="owl-carousel owl-theme">
                    <?php if ( $settings['list'] ) { ?>
                        <?php foreach (  $settings['list'] as $item ) { ?>
                            <div class="item">
                                <div class="slidestart">
                                    <div class="background-image">
                                        <img src="<?php echo $item['list_image']['url'] ?>" alt="">
                                        <div class="contentsiaty">
                                            <p>
                                                <?php echo $item['list_content'] ?>
                                            </p>
                                            <span class="who-told">
                                                    - <?php echo $item['list_title'] ?>
                                                </span>
                                        </div>
                                    </div>
                                </div>
                             </div>
                        <?php } ?>

                    <?php } ?>
                </div>
            </div>
        </div>


        <script>
            jQuery( document ).ready( function( $ ) {

                //Quates slider
                $('#<?php echo $settings['unique_widget_id']?>').owlCarousel({
                    nav: false,
                    dots: true,
                    dotsContainer: '#wpsmart-<?php echo $settings['unique_widget_id']?>',
                    animateOut: 'fadeOut',
                    responsive:{
                        0:{
                            items:1
                        },
                        600:{
                            items:1
                        },
                        1000:{
                            items:1
                        }
                    }
                });


            } );
        </script>
        <?php
	}

	protected function _content_template() {}

    public function render_plain_content( $instance = [] ) {}
}
