<?php
namespace WpsmartSirenTheme\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Social_counter extends Widget_Base {

	public function get_name() {
		return 'Social-Counter-Widget';
	}

	public function get_title() {
		return __( 'Social Counter', 'wpsmart-elementor-plugin' );
	}

	public function get_icon() {
		return 'tts eicon-posts-ticker';
	}

	public function get_categories() {
		return [ 'wpsmart-widget' ];
	}

	public function get_script_depends() {
		return [ 'wpsmart-elementor-plugin' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'wpsmart-elementor-plugin' ),
			]
		);

        $this->add_control(
            'widget_title',
            [
                'label' => __( 'Title', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Default title', 'wpsmart-elementor-plugin' ),
                'placeholder' => __( 'Type your title here', 'wpsmart-elementor-plugin' ),
            ]
        );

        $this->add_control(
            'widget_sub_title',
            [
                'label' => __( 'Sub Title', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Default sub title', 'wpsmart-elementor-plugin' ),
                'placeholder' => __( 'Type your sub-title here', 'wpsmart-elementor-plugin' ),
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => __( 'Main Title Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => 'rgba(0, 0, 0, 0.87)',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .widget-title-section .titles-pack .main-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'sub_title_color',
            [
                'label' => __( 'Sub Title Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => 'rgba(0, 0, 0, 0.54)',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .widget-title-section .titles-pack .sub-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'title_border_color',
            [
                'label' => __( 'Title Bottom Border Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#FC0E0E',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .widget-title-section .titles-pack .main-title .bottom-border' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'social_style',
            [
                'label' => __( 'Select Style', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'blog_post_with_three',
                'options' => [
                    'style_01'  => __( 'List Style', 'wpsmart-elementor-plugin' ),
                    'style_02' => __( 'Color Block Style', 'wpsmart-elementor-plugin' ),
                    'style_03' => __( 'Small Block Style', 'wpsmart-elementor-plugin' ),
                ],
            ]
        );

        $this->add_control(
            'show_facebook',
            [
                'label' => __( 'Show/Hide Facebook Counter', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Hide', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'facebook_title', [
                'label' => __( 'Facebook Title', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Likes' , 'wpsmart-elementor-plugin' ),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'facebook_count', [
                'label' => __( 'Facebook Fans count', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( '12.6K' , 'wpsmart-elementor-plugin' ),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'facebook_url', [
                'label' => __( 'Facebook URL', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'http://facebook.com/your_id' , 'wpsmart-elementor-plugin' ),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'twitter_title', [
                'label' => __( 'Twitter Title', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Followers' , 'wpsmart-elementor-plugin' ),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'instagram_title', [
                'label' => __( 'Instagram Title', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Followers' , 'wpsmart-elementor-plugin' ),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'show_youtube',
            [
                'label' => __( 'Show/Hide Youtube Counter', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Hide', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'youtube_username', [
                'label' => __( 'Youtube Username', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $this->add_control(
            'youtube_title', [
                'label' => __( 'Youtube Title', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Subscribers' , 'wpsmart-elementor-plugin' ),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'show_pintrest',
            [
                'label' => __( 'Show/Hide Pintrest Counter', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Hide', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'pinterest_username', [
                'label' => __( 'Pintrest Username', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $this->add_control(
            'pintesres_title', [
                'label' => __( 'Pinterest Title', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Followers' , 'wpsmart-elementor-plugin' ),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'show_soundcloud',
            [
                'label' => __( 'Show/Hide Soundcloud Counter', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Hide', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'soundcloud_username', [
                'label' => __( 'SoundCloud Username', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $this->add_control(
            'soundcloud_title', [
                'label' => __( 'SoundCloud Title', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Followers' , 'wpsmart-elementor-plugin' ),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'show_vimeo',
            [
                'label' => __( 'Show/Hide Vimeo Counter', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Hide', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'vimeo_username', [
                'label' => __( 'Vimeo Username', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $this->add_control(
            'vimeo_title', [
                'label' => __( 'Vimeo Title', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Followers' , 'wpsmart-elementor-plugin' ),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'show_github',
            [
                'label' => __( 'Show/Hide Github Counter', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Hide', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'github_username', [
                'label' => __( 'Github Username', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $this->add_control(
            'github_title', [
                'label' => __( 'Github Title', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Followers' , 'wpsmart-elementor-plugin' ),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'show_behance',
            [
                'label' => __( 'Show/Hide Behance Counter', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Hide', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'behance_username', [
                'label' => __( 'Behance Username', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $this->add_control(
            'behance_title', [
                'label' => __( 'Behance Title', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Followers' , 'wpsmart-elementor-plugin' ),
                'label_block' => true,
            ]
        );

		$this->end_controls_section();

	}

	protected function render( $instance = [] ) {
		$settings = $this->get_settings_for_display();

        ?>
        <?php   if ($settings['widget_title']) { ?>
        <div class="widget-title-section">
            <div class="titles-pack">
                <?php if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) { ?>
                    <h2 class="main-title"><?php echo $settings['widget_title'] ?>
                        <span class="bottom-border"></span>
                    </h2>
                    <span class="sub-title"><?php echo $settings['widget_sub_title'] ?></span>
                <?php } else {?>
                    <h2 class="main-title" style="color: <?php echo $settings['title_color']; ?>;">
                        <?php echo $settings['widget_title'] ?>
                        <span class="bottom-border" style="background: <?php echo $settings['title_border_color']; ?>;"></span>
                    </h2>
                    <span class="sub-title" style="color: <?php echo $settings['sub_title_color']; ?>;"><?php echo $settings['widget_sub_title'] ?></span>
                <?php } ?>
            </div>
            <div class="title-options">
                    <span class="more icon">
                       <i class="fas fa-thumbs-up"></i>
                    </span>
            </div>
        </div>
        <?php } ?>
        <div class="social-counter-loader">
        </div>
        <?php if ( 'style_01' === $settings['social_style'] ) { ?>
            <div id="wrapper" class="square main-social-counter hidden">
                <?php if ( 'yes' === $settings['show_facebook'] ) { ?>
                    <a href="<?php echo $settings['facebook_url']; ?>" target="_blank" class="item facebook"><i class="fab fa-facebook-f"></i><span class="count"><?php echo $settings['facebook_count'];?></span><?php echo $settings["facebook_title"]; ?></a>
                <?php } ?>
                <?php if ( 'yes' === $settings['show_youtube'] ) { ?>
                <a class="item youtube"><i class="fab fa-youtube"></i><span class="count"></span><?php echo $settings["youtube_title"]; ?></a>
                <?php } ?>
                <?php if ( 'yes' === $settings['show_pintrest'] ) { ?>
                <a class="item pinterest"><i class="fab fa-pinterest"></i><span class="count"></span><?php echo $settings["pintesres_title"]; ?></a>
                <?php } ?>
                <?php if ( 'yes' === $settings['show_soundcloud'] ) { ?>
                <a class="item soundcloud"><i class="fab fa-soundcloud"></i><span class="count"></span><?php echo $settings["soundcloud_title"]; ?></a>
                <?php } ?>
                <?php if ( 'yes' === $settings['show_vimeo'] ) { ?>
                <a class="item vimeo"><i class="fab fa-vimeo-v"></i><span class="count"></span><?php echo $settings["vimeo_title"]; ?></a>
                <?php } ?>
                <?php if ( 'yes' === $settings['show_github'] ) { ?>
                <a class="item github"><i class="fab fa-github"></i><span class="count"></span><?php echo $settings["github_title"]; ?></a>
                <?php } ?>
                <?php if ( 'yes' === $settings['show_behance'] ) { ?>
                <a class="item behance"><i class="fab fa-behance"></i><span class="count"></span><?php echo $settings["behance_title"]; ?></a>
                <?php } ?>
            </div>
        <?php } else if ( 'style_02' === $settings['social_style'] ) { ?>
            <div id="wrapper" class="square main-social-counter hidden">
                <div class="box-style-on">
                    <?php if ( 'yes' === $settings['show_facebook'] ) { ?>
                        <a href="<?php echo $settings['facebook_url']; ?>" target="_blank" class="item facebook"><i class="fab fa-facebook-f"></i><span class="count"><?php echo $settings['facebook_count'];?></span><?php echo $settings["facebook_title"]; ?></a>
                    <?php } ?>
                    <?php if ( 'yes' === $settings['show_youtube'] ) { ?>
                        <a class="item youtube"><i class="fab fa-youtube"></i><span class="count"></span><?php echo $settings["youtube_title"]; ?></a>
                    <?php } ?>
                    <?php if ( 'yes' === $settings['show_pintrest'] ) { ?>
                        <a class="item pinterest"><i class="fab fa-pinterest"></i><span class="count"></span><?php echo $settings["pintesres_title"]; ?></a>
                    <?php } ?>
                    <?php if ( 'yes' === $settings['show_soundcloud'] ) { ?>
                        <a class="item soundcloud"><i class="fab fa-soundcloud"></i><span class="count"></span><?php echo $settings["soundcloud_title"]; ?></a>
                    <?php } ?>
                    <?php if ( 'yes' === $settings['show_vimeo'] ) { ?>
                        <a class="item vimeo"><i class="fab fa-vimeo-v"></i><span class="count"></span><?php echo $settings["vimeo_title"]; ?></a>
                    <?php } ?>
                    <?php if ( 'yes' === $settings['show_github'] ) { ?>
                        <a class="item github"><i class="fab fa-github"></i><span class="count"></span><?php echo $settings["github_title"]; ?></a>
                    <?php } ?>
                    <?php if ( 'yes' === $settings['show_behance'] ) { ?>
                        <a class="item behance"><i class="fab fa-behance"></i><span class="count"></span><?php echo $settings["behance_title"]; ?></a>
                    <?php } ?>
                </div>
            </div>
        <?php } else if ( 'style_03' === $settings['social_style'] ) { ?>
            <div id="wrapper" class="square main-social-counter hidden">
                <div class="simple-block">
                    <?php if ( 'yes' === $settings['show_facebook'] ) { ?>
                        <a href="<?php echo $settings['facebook_url']; ?>" target="_blank" class="item facebook"><i class="fab fa-facebook-f"></i><span class="count"><?php echo $settings['facebook_count'];?></span><?php echo $settings["facebook_title"]; ?></a>
                    <?php } ?>
                    <?php if ( 'yes' === $settings['show_youtube'] ) { ?>
                        <a class="item youtube"><i class="fab fa-youtube"></i><span class="count"></span><?php echo $settings["youtube_title"]; ?></a>
                    <?php } ?>
                    <?php if ( 'yes' === $settings['show_pintrest'] ) { ?>
                        <a class="item pinterest"><i class="fab fa-pinterest"></i><span class="count"></span><?php echo $settings["pintesres_title"]; ?></a>
                    <?php } ?>
                    <?php if ( 'yes' === $settings['show_soundcloud'] ) { ?>
                        <a class="item soundcloud"><i class="fab fa-soundcloud"></i><span class="count"></span><?php echo $settings["soundcloud_title"]; ?></a>
                    <?php } ?>
                    <?php if ( 'yes' === $settings['show_vimeo'] ) { ?>
                        <a class="item vimeo"><i class="fab fa-vimeo-v"></i><span class="count"></span><?php echo $settings["vimeo_title"]; ?></a>
                    <?php } ?>
                    <?php if ( 'yes' === $settings['show_github'] ) { ?>
                        <a class="item github"><i class="fab fa-github"></i><span class="count"></span><?php echo $settings["github_title"]; ?></a>
                    <?php } ?>
                    <?php if ( 'yes' === $settings['show_behance'] ) { ?>
                        <a class="item behance"><i class="fab fa-behance"></i><span class="count"></span><?php echo $settings["behance_title"]; ?></a>
                    <?php } ?>
                </div>
            </div>
        <?php } ?>

        <script>
            jQuery(function ($){

                $('#wrapper').SocialCounter({
                    //Get Usernames
                    youtube_user: '<?php echo $settings["youtube_username"]; ?>',
                    pinterest_user: '<?php echo $settings["pinterest_username"]; ?>',
                    soundcloud_user_id: '<?php echo $settings["soundcloud_username"]; ?>',
                    vimeo_user: '<?php echo $settings["vimeo_username"]; ?>',
                    github_user: '<?php echo $settings["github_username"]; ?>',
                    behance_user: '<?php echo $settings["behance_username"]; ?>',
                    <?php if (function_exists('WPS_framework_init')) { ?>
                    //Get Access Tokens,keys,client_ids
                    youtube_key:'<?php echo wps_get_option('youtube_key_wps' ); ?>',
                    soundcloud_client_id:'<?php echo wps_get_option('sound_cloud_wps' ); ?>',
                    vimeo_token:'<?php echo wps_get_option('vimeo_token_wps' ); ?>',
                    behance_client_id:'<?php echo wps_get_option('behance_token_wps' ); ?>',
                    <?php } ?>
                });
            });
        </script>

        <?php
	}

	protected function _content_template() {}

    public function render_plain_content( $instance = [] ) {}
}
