<?php
namespace WpsmartSirenTheme\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Social_links extends Widget_Base {

	public function get_name() {
		return 'Social-Link-Widget';
	}

	public function get_title() {
		return __( 'Social links', 'wpsmart-elementor-plugin' );
	}

	public function get_icon() {
		return 'eicon-social-icons';
	}

	public function get_categories() {
		return [ 'wpsmart-widget' ];
	}

	public function get_script_depends() {
		return [ 'wpsmart-elementor-plugin' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'wpsmart-elementor-plugin' ),
			]
		);

        $this->add_control(
            'show_hide_border',
            [
                'label' => __( 'Show/Hide Border', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Enable', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Disable', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

        $this->add_control(
            'background_links',
            [
                'label' => __( 'Background color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#ffffff',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .social-links' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'social_link_color',
            [
                'label' => __( 'Social Icon color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#333333',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .social-links ul li a i' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'line_heigh_social',
            [
                'label' => __( 'Change Line Hight, First Disable Border and use', 'wpsmart-elementor-plugin' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 80,
                        'step' => 1,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 36,
                ],
                'selectors' => [
                    '{{WRAPPER}} .social-links ul.remove-border li a i' => 'line-height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'youtube_url', [
                'label' => __( 'Youtube URL', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $this->add_control(
            'facebook_url', [
                'label' => __( 'Facebook URL', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $this->add_control(
            'twitter_url', [
                'label' => __( 'Twitter URL', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $this->add_control(
            'linkedin_url', [
                'label' => __( 'Linkedin URL', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $this->add_control(
            'instagram_url', [
                'label' => __( 'Instagram URL', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $this->add_control(
            'pinterest_url', [
                'label' => __( 'Pinterest URL', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $this->add_control(
            'twitch_url', [
                'label' => __( 'Twitch URL', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $this->add_control(
            'vimeo_url', [
                'label' => __( 'Vimeo URL', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

		$this->end_controls_section();

	}

	protected function render( $instance = [] ) {
		$settings = $this->get_settings_for_display();

        ?>

        <?php if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) { ?>
            <div class="social-links">
                <ul <?php if ( 'yes' === $settings['show_hide_border'] ) { ?> class="remove-border" <?php } ?>>
                    <?php if ( $settings['youtube_url'] ) { ?>
                        <li class="youtube">
                            <a href="<?php echo $settings['youtube_url'] ?>">
                                <i class="fab fa-youtube"></i>
                            </a>
                        </li>
                    <?php } ?>
                    <?php if ( $settings['facebook_url'] ) { ?>
                        <li class="facebook">
                            <a href="<?php echo $settings['facebook_url'] ?>">
                                <i class="fab fa-facebook-f"></i>
                            </a>
                        </li>
                    <?php } ?>
                    <?php if ( $settings['twitter_url'] ) { ?>
                        <li class="twitter">
                            <a href="<?php echo $settings['twitter_url'] ?>">
                                <i class="fab fa-twitter"></i>
                            </a>
                        </li>
                    <?php } ?>
                    <?php if ( $settings['linkedin_url'] ) { ?>
                        <li class="linkedin">
                            <a href="<?php echo $settings['linkedin_url'] ?>">
                                <i class="fab fa-linkedin-in"></i>
                            </a>
                        </li>
                    <?php } ?>
                    <?php if ( $settings['instagram_url'] ) { ?>
                        <li class="instagram">
                            <a href="<?php echo $settings['instagram_url'] ?>">
                                <i class="fab fa-instagram"></i>
                            </a>
                        </li>
                    <?php } ?>
                    <?php if ( $settings['pinterest_url'] ) { ?>
                        <li class="pintrest">
                            <a href="<?php echo $settings['pinterest_url'] ?>">
                                <i class="fab fa-pinterest-p"></i>
                            </a>
                        </li>
                    <?php } ?>
                    <?php if ( $settings['twitch_url'] ) { ?>
                        <li class="twitch">
                            <a href="<?php echo $settings['twitch_url'] ?>">
                                <i class="fab fa-twitch"></i>
                            </a>
                        </li>
                    <?php } ?>
                    <?php if ( $settings['vimeo_url'] ) { ?>
                        <li class="vimeo">
                            <a href="<?php echo $settings['vimeo_url'] ?>">
                                <i class="fab fa-vimeo-v"></i>
                            </a>
                        </li>
                    <?php } ?>
                </ul>
            </div>
        <?php } else {?>
            <div class="social-links" style="background: <?php echo $settings['background_links']; ?>;">
                <ul <?php if ( 'yes' === $settings['show_hide_border'] ) { ?> class="remove-border" <?php } ?>>
                    <?php if ( $settings['youtube_url'] ) { ?>
                        <li class="youtube" style="line-height: <?php echo $settings['line_heigh_social']['size']; ?><?php echo $settings['line_heigh_social']['unit']; ?>; height: <?php echo $settings['line_heigh_social']['size']; ?><?php echo $settings['line_heigh_social']['unit']; ?>">
                            <a href="<?php echo $settings['youtube_url'] ?>">
                                <i class="fab fa-youtube" style="color: <?php echo $settings['social_link_color']; ?>;"></i>
                            </a>
                        </li>
                    <?php } ?>
                    <?php if ( $settings['facebook_url'] ) { ?>
                        <li class="facebook" style="line-height: <?php echo $settings['line_heigh_social']['size']; ?><?php echo $settings['line_heigh_social']['unit']; ?>; height: <?php echo $settings['line_heigh_social']['size']; ?><?php echo $settings['line_heigh_social']['unit']; ?>">
                            <a href="<?php echo $settings['facebook_url'] ?>">
                                <i class="fab fa-facebook-f" style="color: <?php echo $settings['social_link_color']; ?>;"></i>
                            </a>
                        </li>
                    <?php } ?>
                    <?php if ( $settings['twitter_url'] ) { ?>
                        <li class="twitter" style="line-height: <?php echo $settings['line_heigh_social']['size']; ?><?php echo $settings['line_heigh_social']['unit']; ?>; height: <?php echo $settings['line_heigh_social']['size']; ?><?php echo $settings['line_heigh_social']['unit']; ?>">
                            <a href="<?php echo $settings['twitter_url'] ?>">
                                <i class="fab fa-twitter" style="color: <?php echo $settings['social_link_color']; ?>;"></i>
                            </a>
                        </li>
                    <?php } ?>
                    <?php if ( $settings['linkedin_url'] ) { ?>
                        <li class="linkedin" style="line-height: <?php echo $settings['line_heigh_social']['size']; ?><?php echo $settings['line_heigh_social']['unit']; ?>; height: <?php echo $settings['line_heigh_social']['size']; ?><?php echo $settings['line_heigh_social']['unit']; ?>">
                            <a href="<?php echo $settings['linkedin_url'] ?>">
                                <i class="fab fa-linkedin-in" style="color: <?php echo $settings['social_link_color']; ?>;"></i>
                            </a>
                        </li>
                    <?php } ?>
                    <?php if ( $settings['instagram_url'] ) { ?>
                        <li class="instagram" style="line-height: <?php echo $settings['line_heigh_social']['size']; ?><?php echo $settings['line_heigh_social']['unit']; ?>; height: <?php echo $settings['line_heigh_social']['size']; ?><?php echo $settings['line_heigh_social']['unit']; ?>">
                            <a href="<?php echo $settings['instagram_url'] ?>">
                                <i class="fab fa-instagram" style="color: <?php echo $settings['social_link_color']; ?>;"></i>
                            </a>
                        </li>
                    <?php } ?>
                    <?php if ( $settings['pinterest_url'] ) { ?>
                        <li class="pintrest" style="line-height: <?php echo $settings['line_heigh_social']['size']; ?><?php echo $settings['line_heigh_social']['unit']; ?>; height: <?php echo $settings['line_heigh_social']['size']; ?><?php echo $settings['line_heigh_social']['unit']; ?>">
                            <a href="<?php echo $settings['pinterest_url'] ?>">
                                <i class="fab fa-pinterest-p" style="color: <?php echo $settings['social_link_color']; ?>;"></i>
                            </a>
                        </li>
                    <?php } ?>
                    <?php if ( $settings['twitch_url'] ) { ?>
                        <li class="twitch" style="line-height: <?php echo $settings['line_heigh_social']['size']; ?><?php echo $settings['line_heigh_social']['unit']; ?>; height: <?php echo $settings['line_heigh_social']['size']; ?><?php echo $settings['line_heigh_social']['unit']; ?>">
                            <a href="<?php echo $settings['twitch_url'] ?>">
                                <i class="fab fa-twitch" style="color: <?php echo $settings['social_link_color']; ?>;"></i>
                            </a>
                        </li>
                    <?php } ?>
                    <?php if ( $settings['vimeo_url'] ) { ?>
                        <li class="vimeo" style="line-height: <?php echo $settings['line_heigh_social']['size']; ?><?php echo $settings['line_heigh_social']['unit']; ?>; height: <?php echo $settings['line_heigh_social']['size']; ?><?php echo $settings['line_heigh_social']['unit']; ?>">
                            <a href="<?php echo $settings['vimeo_url'] ?>">
                                <i class="fab fa-vimeo-v" style="color: <?php echo $settings['social_link_color']; ?>;"></i>
                            </a>
                        </li>
                    <?php } ?>
                </ul>
            </div>
        <?php } ?>



        <?php
	}

	protected function _content_template() {}

    public function render_plain_content( $instance = [] ) {}
}
