<?php
namespace WpsmartSirenTheme\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Tag_list extends Widget_Base {

	public function get_name() {
		return 'all_tag_list';
	}

	public function get_title() {
		return __( 'Post Tags', 'wpsmart-elementor-plugin' );
	}

	public function get_icon() {
		return 'eicon-meta-data';
	}

    public function get_categories() {
		return [ 'wpsmart-widget' ];
	}

	public function get_script_depends() {
		return [ 'wpsmart-elementor-plugin' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'wpsmart-elementor-plugin' ),
			]
		);

        $this->add_control(
            'widget_title',
            [
                'label' => __( 'Title', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Default title', 'wpsmart-elementor-plugin' ),
                'placeholder' => __( 'Type your title here', 'wpsmart-elementor-plugin' ),
            ]
        );

        $this->add_control(
            'widget_sub_title',
            [
                'label' => __( 'Sub Title', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Default sub title', 'wpsmart-elementor-plugin' ),
                'placeholder' => __( 'Type your sub-title here', 'wpsmart-elementor-plugin' ),
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => __( 'Main Title Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => 'rgba(0, 0, 0, 0.87)',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .widget-title-section .titles-pack .main-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'sub_title_color',
            [
                'label' => __( 'Sub Title Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => 'rgba(0, 0, 0, 0.54)',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .widget-title-section .titles-pack .sub-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'title_border_color',
            [
                'label' => __( 'Title Bottom Border Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#FC0E0E',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .widget-title-section .titles-pack .main-title .bottom-border' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'tag_count',
            [
                'label' => __( 'How many blog post', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => __( '5', 'wpsmart-elementor-plugin' ),
            ]
        );

		$this->end_controls_section();

		//Style Section
		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Style', 'wpsmart-elementor-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

        $this->add_control(
            'box-style-enable',
            [
                'label' => __( 'Card Style Enable', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Enable', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Disable', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

        $this->add_control(
            'dark_theme_active',
            [
                'label' => __( 'Dark Theme Activate Enable', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Enable', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Disable', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );


		$this->end_controls_section();
	}

	protected function render( $instance = [] ) {
		$settings = $this->get_settings_for_display();

        ?>
        <div class="tags-cloud <?php if ( 'yes' === $settings['box-style-enable'] ) { ?> card-design <?php } ?>">
        <?php   if ($settings['widget_title']) { ?>
            <div class="widget-title-section <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>">
                <div class="titles-pack">
                    <?php if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) { ?>
                        <h2 class="main-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>"><?php echo $settings['widget_title'] ?>
                            <span class="bottom-border"></span>
                        </h2>
                        <span class="sub-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>"><?php echo $settings['widget_sub_title'] ?></span>
                    <?php } else {?>
                        <h2 class="main-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>" style="color: <?php echo $settings['title_color']; ?>;">
                            <?php echo $settings['widget_title'] ?>
                            <span class="bottom-border" style="background: <?php echo $settings['title_border_color']; ?>;"></span>
                        </h2>
                        <span class="sub-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>" style="color: <?php echo $settings['sub_title_color']; ?>;"><?php echo $settings['widget_sub_title'] ?></span>
                    <?php } ?>
                </div>
                <div class="title-options">
                    <a href="<?php echo get_category_link( $settings['cat_type'] ); ?>" class="more <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>"><?php echo esc_attr_e( 'More', 'siren' ); ?></a>
                </div>
            </div>
            <?php } ?>
            <div class="all-post-tags">
                <?php
                $tags =get_tags(array(
                    'hide_empty' => false,
                    'number' => $settings['tag_count']
                ));
                if ( $tags ) :
                    foreach ( $tags as $tag ) : ?>
                        <li><a href="<?php echo esc_url( get_tag_link( $tag->term_id ) ); ?>" title="<?php echo esc_attr( $tag->name ); ?>"><?php echo esc_html( $tag->name ); ?></a></li>
                    <?php endforeach; ?>
                <?php endif; ?>
            </div>

        </div>


        <?php
	}

	protected function _content_template() {}

    public function render_plain_content( $instance = [] ) {}
}
