<?php
namespace WpsmartSirenTheme\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Tag_list_post_widget extends Widget_Base {

	public function get_name() {
		return 'Tag-List-Post-Widget';
	}

	public function get_title() {
		return __( 'Dark Post List', 'wpsmart-elementor-plugin' );
	}

	public function get_icon() {
		return 'eicon-text';
	}

	public function get_categories() {
		return [ 'wpsmart-widget' ];
	}

	public function get_script_depends() {
		return [ 'wpsmart-elementor-plugin' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'wpsmart-elementor-plugin' ),
			]
		);

        $this->add_control(
            'widget_title',
            [
                'label' => __( 'Title', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Default title', 'wpsmart-elementor-plugin' ),
                'placeholder' => __( 'Type your title here', 'wpsmart-elementor-plugin' ),
            ]
        );

        $this->add_control(
            'unique_widget_id',
            [
                'label' => __( 'Type Unique ID', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'placeholder' => __( 'uniqueid_2545', 'wpsmart-elementor-plugin' ),
                'default' => __( 'tag_list_unique_id1991', 'wpsmart-elementor-plugin' ),
            ]
        );

        $this->add_control(
            'widget_height_here',
            [
                'label' => __( 'Set Height Of the Widget', 'wpsmart-elementor-plugin' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 200,
                        'max' => 1000,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 40,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 350,
                ],
                'selectors' => [
                    '{{WRAPPER}} .dark-post-list-scroll .post-content-scroll .dark-list-container' => 'height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'post_count',
            [
                'label' => __( 'How many blog post', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => __( '10', 'wpsmart-elementor-plugin' ),
                'min' => 3,
                'max' => 30,
            ]
        );

        $this->add_control(
            'cat_type',
            [
                'label' => __( 'Select Category', 'essential-addons-elementor' ),
                'type' => Controls_Manager::SELECT,
                'options' => wpsmart_post_type_categories(),
                'default' => 'post',

            ]
        );

        $this->add_control(
            'show_first_tag',
            [
                'label' => __( 'Show First Tag', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Hide', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'show_posted_date',
            [
                'label' => __( 'Show Posted Date', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Hide', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'Show_hide_comment_count',
            [
                'label' => __( 'Show Comment Count Date', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Hide', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

		$this->end_controls_section();

		//Style Section
		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Style', 'wpsmart-elementor-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

        $this->add_control(
            'post_view_count_desktop',
            [
                'label' => __( 'Post Per Desktop View', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => __( '4', 'wpsmart-elementor-plugin' ),
                'min' => 2,
                'max' => 6,
            ]
        );


        $this->add_control(
            'post_view_count_tablet',
            [
                'label' => __( 'Post Per Tablet View', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => __( '2', 'wpsmart-elementor-plugin' ),
                'min' => 2,
                'max' => 4,
            ]
        );


        $this->add_control(
            'post_view_count_mobile',
            [
                'label' => __( 'Post Per Mobile View', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => __( '1', 'wpsmart-elementor-plugin' ),
                'min' => 1,
                'max' => 3,
            ]
        );

        $this->add_control(
            'dark_theme_active',
            [
                'label' => __( 'Dark Theme Activate Enable', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Enable', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Disable', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );


		$this->end_controls_section();
	}

	protected function render( $instance = [] ) {
		$settings = $this->get_settings_for_display();

        ?>


        <div class="dark-post-list-scroll">
            <?php   if ($settings['widget_title']) { ?>
                <div class="widget-title-section <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>">
                    <div class="titles-pack">
                        <?php if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) { ?>
                            <h2 class="main-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>"><?php echo $settings['widget_title'] ?>
                                <span class="bottom-border"></span>
                            </h2>
                            <span class="sub-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>"><?php echo $settings['widget_sub_title'] ?></span>
                        <?php } else {?>
                            <h2 class="main-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>" style="color: <?php echo $settings['title_color']; ?>;">
                                <?php echo $settings['widget_title'] ?>
                                <span class="bottom-border" style="background: <?php echo $settings['title_border_color']; ?>;"></span>
                            </h2>
                            <span class="sub-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>" style="color: <?php echo $settings['sub_title_color']; ?>;"><?php echo $settings['widget_sub_title'] ?></span>
                        <?php } ?>
                    </div>
                </div>
            <?php } ?>
            <div class="post-content-scroll">
                <div class="dark-list-container" id="<?php echo $settings['unique_widget_id'] ?>">
            <?php
        global $post;

        $magaz_header = get_posts( array(
            'posts_per_page' => $settings['post_count'],
            'category'       => $settings['cat_type']
        ) );
            if ( $magaz_header ) {
                foreach ( $magaz_header as $post ) :
                    setup_postdata( $post ); ?>
                    <?php $post_tags = get_the_tags();
                    if ($post_tags) { ?>
                    <div class="dark-post-tags">
                        <?php the_post_thumbnail('siren-medium-post-thumb'); ?>
                        <div class="dark-color-spam-layer"></div>
                        <div class="post-content-start">
                            <div class="left-side-tag" >
                                #<?php
                                echo $post_tags[0]->name;
                                ?>
                            </div>
                            <div class="right-content">
                                <a href="<?php the_permalink(); ?>">
                                    <h2><?php the_title(); ?></h2>
                                </a>
                            </div>
                        </div>
                    </div>
                    <?php } ?>
                    <?php
                    endforeach;
                        wp_reset_postdata();
                    } ?>
                </div>
            </div>
        </div>

        <script>
            jQuery(function ($){
                //SimpleSidebar
                new SimpleBar(document.getElementById('<?php echo $settings['unique_widget_id'] ?>'));

            });
        </script>


        <?php
	}

	protected function _content_template() {}

    public function render_plain_content( $instance = [] ) {}
}
