<?php
namespace WpsmartSirenTheme\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Widget_custom_titles extends Widget_Base {

	public function get_name() {
		return 'Widget-titles';
	}

	public function get_title() {
		return __( 'Widget Titles', 'wpsmart-elementor-plugin' );
	}

	public function get_icon() {
		return 'eicon-t-letter';
	}

	public function get_categories() {
		return [ 'wpsmart-widget' ];
	}

	public function get_script_depends() {
		return [ 'wpsmart-elementor-plugin' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'wpsmart-elementor-plugin' ),
			]
		);

        $this->add_control(
            'header_widget_style',
            [
                'label' => __( 'Widget Title Style', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'widget_title_style_1',
                'options' => [
                    'widget_title_style_1'  => __( 'Style 01', 'wpsmart-elementor-plugin' ),
                    'widget_title_style_2' => __( 'Style 02', 'wpsmart-elementor-plugin' ),
                    'widget_title_style_3' => __( 'Style 03', 'wpsmart-elementor-plugin' ),
                ],
            ]
        );

        $this->add_control(
            'dark_theme_active',
            [
                'label' => __( 'Dark Theme Activate Enable', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Enable', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Disable', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

        $this->add_control(
            'widget_title',
            [
                'label' => __( 'Title', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Default title', 'wpsmart-elementor-plugin' ),
                'placeholder' => __( 'Type your title here', 'wpsmart-elementor-plugin' ),
            ]
        );

        $this->add_control(
            'widget_sub_title',
            [
                'label' => __( 'Sub Title', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Default sub title', 'wpsmart-elementor-plugin' ),
                'placeholder' => __( 'Type your sub-title here', 'wpsmart-elementor-plugin' ),
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => __( 'Main Title Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => 'rgba(0, 0, 0, 0.87)',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .widget-title-section .titles-pack .main-title' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .widget-title-section.custom-title-block.custom-style-3 .titles-pack h2.main-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'sub_title_color',
            [
                'label' => __( 'Sub Title Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => 'rgba(0, 0, 0, 0.54)',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .widget-title-section .titles-pack .sub-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'title_border_color',
            [
                'label' => __( 'Title Bottom Border Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#FC0E0E',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .widget-title-section .titles-pack .main-title .bottom-border, {{WRAPPER}} .widget-title-section.custom-title-block.custom-style-2 .titles-pack h2.main-title, {{WRAPPER}} .widget-title-section.custom-title-block.custom-style-3 .titles-pack h2.main-title' => 'background: {{VALUE}}',
                    '{{WRAPPER}} .widget-title-section.custom-title-block.custom-style-3 .titles-pack .bottom-border' => 'background: {{VALUE}}',
                    '{{WRAPPER}} .popular-posts .popular-post-list .other-post-list ul li:hover .content-of-post-list h2' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .widget-title-section.custom-title-block.custom-style-2' => 'border-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'show_hide_more_link',
            [
                'label' => __( 'Show More Links From Title', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Hide', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'cat_type',
            [
                'label' => __( 'Select Category If This Block Need', 'essential-addons-elementor' ),
                'type' => Controls_Manager::SELECT,
                'options' => wpsmart_post_type_categories(),
                'default' => 'post',

            ]
        );


		$this->end_controls_section();

		//Style Section
		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Style', 'wpsmart-elementor-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);


		$this->end_controls_section();
	}

	protected function render( $instance = [] ) {
		$settings = $this->get_settings_for_display();

        if ( 'widget_title_style_1' === $settings['header_widget_style'] ) { ?>

            <div class="widget-title-section custom-title-block <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>">
                <div class="titles-pack">
                    <?php if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) { ?>
                        <h2 class="main-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>"><?php echo $settings['widget_title'] ?>
                            <span class="bottom-border"></span>
                        </h2>
                        <span class="sub-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>"><?php echo $settings['widget_sub_title'] ?></span>
                    <?php } else {?>
                        <h2 class="main-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>" style="color: <?php echo $settings['title_color']; ?>;">
                            <?php echo $settings['widget_title'] ?>
                            <span class="bottom-border" style="background: <?php echo $settings['title_border_color']; ?>;"></span>
                        </h2>
                        <span class="sub-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>" style="color: <?php echo $settings['sub_title_color']; ?>;"><?php echo $settings['widget_sub_title'] ?></span>
                    <?php } ?>
                </div>
                <?php if ( 'yes' === $settings['show_hide_more_link'] ) { ?>
                <div class="title-options">
                    <a href="<?php echo get_category_link( $settings['cat_type'] ); ?>" class="more <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>"><?php echo esc_attr_e( 'More', 'siren' ); ?></a>
                </div>
                <?php } ?>
            </div>
        <?php } else if ( 'widget_title_style_2' === $settings['header_widget_style'] ) { ?>

            <div class="widget-title-section custom-style-2 custom-title-block <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>" <?php if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) { } else {?> style="border-color: <?php echo $settings['title_border_color']; ?>;" <?php } ?>>
                <div class="titles-pack">
                    <?php if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) { ?>
                        <h2 class="main-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>">
                            <?php echo $settings['widget_title'] ?>
                        </h2>
                    <?php } else {?>
                        <h2 class="main-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>" style="color: <?php echo $settings['title_color'];  ?>; background: <?php echo $settings['title_border_color']; ?>;">
                            <?php echo $settings['widget_title'] ?>
                        </h2>
                    <?php } ?>
                </div>
                <?php if ( 'yes' === $settings['show_hide_more_link'] ) { ?>
                    <div class="title-options">
                        <a href="<?php echo get_category_link( $settings['cat_type'] ); ?>" class="more <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>"><?php echo esc_attr_e( 'More', 'siren' ); ?></a>
                    </div>
                <?php } ?>
            </div>

        <?php } else if ( 'widget_title_style_3' === $settings['header_widget_style'] ) { ?>

            <div class="widget-title-section custom-style-3 custom-title-block <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>" <?php if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) { } else {?> style="border-color: <?php echo $settings['title_border_color']; ?>;" <?php } ?>>
                <div class="titles-pack">
                    <?php if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) { ?>
                        <h2 class="main-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>">
                            <?php echo $settings['widget_title'] ?>
                        </h2>
                        <span class="bottom-border"></span>
                    <?php } else {?>
                        <h2 class="main-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>" style="color: <?php echo $settings['title_color'];  ?>; background: <?php echo $settings['title_border_color']; ?>;">
                            <?php echo $settings['widget_title'] ?>
                        </h2>
                        <span class="bottom-border" style="background: <?php echo $settings['title_border_color']; ?>;"></span>
                    <?php } ?>
                    <?php if ( 'yes' === $settings['show_hide_more_link'] ) { ?>
                        <div class="title-options">
                            <a href="<?php echo get_category_link( $settings['cat_type'] ); ?>" class="more <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>"><?php echo esc_attr_e( 'More', 'siren' ); ?></a>
                        </div>
                    <?php } ?>
                </div>
            </div>

        <?php }
	}

	protected function _content_template() {}

    public function render_plain_content( $instance = [] ) {}
}
