<?php
namespace WpsmartSirenTheme\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Woocommerce_shopping_cart extends Widget_Base {

	public function get_name() {
		return 'woo-shopping-cart';
	}
	public function get_title() {
		return __( 'Woocommerce Shopping Cart', 'wpsmart-elementor-plugin' );
	}
	public function get_icon() {
		return 'tts eicon-posts-ticker';
	}
	public function get_categories() {
		return [ 'wpsmart-widget' ];
	}
	public function get_script_depends() {
		return [ 'wpsmart-elementor-plugin' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'wpsmart-elementor-plugin' ),
			]
		);


        $this->add_control(
            'cart_icon',
            [
                'label' => __( 'Cart Icon Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => 'rgba(0, 0, 0, 0.54)',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .cart-and-counter i' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'cart__count_color_bg',
            [
                'label' => __( 'Cart Count Background Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#FC0E0E',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .cart-and-counter a' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'cart__count_color_font',
            [
                'label' => __( 'Cart Count Text Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#fff',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .cart-and-counter a' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'font_size_slider',
            [
                'label' => __( 'Main Font size', 'wpsmart-elementor-plugin' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 3,
                        'max' => 60,
                        'step' => 1,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 14,
                ],
                'selectors' => [
                    '{{WRAPPER}} .cart-and-counter' => 'padding: {{SIZE}}{{UNIT}} 0;',
                ],
            ]
        );

		$this->end_controls_section();

	}

	protected function render( $instance = [] ) {
		$settings = $this->get_settings_for_display();

            if ( class_exists( 'WooCommerce' ) ) { ?>
                <?php if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) { ?>
                    <div class="cart-and-counter">
                        <i class="fas fa-shopping-cart"></i>
                        <a class="cart-contents" href="#" title="View your shopping cart">64</a>
                    </div>
                <?php } else {?>
                <div class="cart-and-counter">
                    <i class="fas fa-shopping-cart"></i>
                    <?php global $woocommerce; ?>
                    <a class="cart-contents" href="<?php echo $woocommerce->cart->get_cart_url(); ?>" title="<?php _e('View your shopping cart', 'woothemes'); ?>">
                        <?php echo sprintf(_n('%d', '%d', $woocommerce->cart->cart_contents_count, 'woothemes'), $woocommerce->cart->cart_contents_count);?>
                    </a>
                </div>
                <?php } ?>
            <?php } else {
                echo __( 'Please install Woocommerce Plugin' );
            } ?>


        <?php
	}

	protected function _content_template() {}

    public function render_plain_content( $instance = [] ) {}
}
