<?php
namespace WpsmartSirenTheme\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Woocommerce_products_by extends Widget_Base {

	public function get_name() {
		return 'woo-products-by-cat-category';
	}
	public function get_title() {
		return __( 'Woocommerce Products', 'wpsmart-elementor-plugin' );
	}
	public function get_icon() {
		return 'tts eicon-posts-ticker';
	}
	public function get_categories() {
		return [ 'wpsmart-widget' ];
	}
	public function get_script_depends() {
		return [ 'wpsmart-elementor-plugin' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'wpsmart-elementor-plugin' ),
			]
		);

        $this->add_control(
            'widget_title',
            [
                'label' => __( 'Title', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Default title', 'wpsmart-elementor-plugin' ),
                'placeholder' => __( 'Type your title here', 'wpsmart-elementor-plugin' ),
            ]
        );

        $this->add_control(
            'widget_sub_title',
            [
                'label' => __( 'Sub Title', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'Default sub title', 'wpsmart-elementor-plugin' ),
                'placeholder' => __( 'Type your sub-title here', 'wpsmart-elementor-plugin' ),
            ]
        );

        $this->add_control(
            'store_link',
            [
                'label' => __( 'Link to Store', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'placeholder' => __( 'Type your Store URL', 'wpsmart-elementor-plugin' ),
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => __( 'Main Title Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => 'rgba(0, 0, 0, 0.87)',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .widget-title-section .titles-pack .main-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'sub_title_color',
            [
                'label' => __( 'Sub Title Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => 'rgba(0, 0, 0, 0.54)',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .widget-title-section .titles-pack .sub-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'title_border_color',
            [
                'label' => __( 'Title Bottom Border Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#FC0E0E',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .widget-title-section .titles-pack .main-title .bottom-border' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'unique_widget_id',
            [
                'label' => __( 'Type Unique ID', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'placeholder' => __( 'uniqueid_2545', 'wpsmart-elementor-plugin' ),
                'default' => __( 'woocommerce_list_id_9859', 'wpsmart-elementor-plugin' ),
            ]
        );

        $this->add_control(
            'post_count',
            [
                'label' => __( 'Products', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => __( '5', 'wpsmart-elementor-plugin' ),
                'max' => 10,
            ]
        );

        $this->add_control(
            'cat_type',
            [
                'label' => __( 'Select Category', 'essential-addons-elementor' ),
                'type' => Controls_Manager::SELECT,
                'options' => wpsmart_woocommerce_product_categories(),
                'default' => 'post',

            ]
        );


        $this->add_control(
            'post_tags_color',
            [
                'label' => __( 'Buy Button Color Color', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#FC0E0E',
                'scheme' => [
                    'type' => \Elementor\Scheme_Color::get_type(),
                    'value' => \Elementor\Scheme_Color::COLOR_1,
                ],
                'selectors' => [
                    '{{WRAPPER}} .add_to_cart_button, .product_type_variable' => 'background: {{VALUE}}; border-color: {{VALUE}};',
                ],
            ]
        );

		$this->end_controls_section();

		//Style Section
		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Style', 'wpsmart-elementor-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

        $this->add_control(
            'post_view_count_desktop',
            [
                'label' => __( 'Post Per Desktop View', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => __( '4', 'wpsmart-elementor-plugin' ),
                'min' => 2,
                'max' => 6,
            ]
        );


        $this->add_control(
            'post_view_count_tablet',
            [
                'label' => __( 'Post Per Tablet View', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => __( '2', 'wpsmart-elementor-plugin' ),
                'min' => 2,
                'max' => 4,
            ]
        );


        $this->add_control(
            'post_view_count_mobile',
            [
                'label' => __( 'Post Per Mobile View', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => __( '1', 'wpsmart-elementor-plugin' ),
                'min' => 1,
                'max' => 3,
            ]
        );

        $this->add_control(
            'box-style-enable',
            [
                'label' => __( 'Card Style Enable', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Enable', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Disable', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

        $this->add_control(
            'dark_theme_active',
            [
                'label' => __( 'Dark Theme Activate Enable', 'wpsmart-elementor-plugin' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Enable', 'wpsmart-elementor-plugin' ),
                'label_off' => __( 'Disable', 'wpsmart-elementor-plugin' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

		$this->end_controls_section();
	}

	protected function render( $instance = [] ) {
		$settings = $this->get_settings_for_display();
        ?>
        <div class="modern-postby <?php if ( 'yes' === $settings['box-style-enable'] ) { ?> card-design <?php } ?>">
            <?php   if ($settings['widget_title']) { ?>
                <div class="widget-title-section <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>">
                <div class="titles-pack">
                    <?php if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) { ?>
                        <h2 class="main-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>"><?php echo $settings['widget_title'] ?>
                            <span class="bottom-border"></span>
                        </h2>
                        <span class="sub-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>"><?php echo $settings['widget_sub_title'] ?></span>
                    <?php } else {?>
                        <h2 class="main-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>" style="color: <?php echo $settings['title_color']; ?>;">
                            <?php echo $settings['widget_title'] ?>
                            <span class="bottom-border" style="background: <?php echo $settings['title_border_color']; ?>;"></span>
                        </h2>
                        <span class="sub-title <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>" style="color: <?php echo $settings['sub_title_color']; ?>;"><?php echo $settings['widget_sub_title'] ?></span>
                    <?php } ?>
                </div>
                <div class="title-options">
                    <a href="<?php echo $settings['store_link'];?>" class="more <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>" target="_blank"><i class="fas fa-store"></i> Store</a>
                </div>
            </div>
            <?php } ?>

            <?php
            if ( class_exists( 'WooCommerce' ) ) { ?>

                    <?php

                    $number_of_posts = $settings['post_count'];
                    $post_by_woo_category = $settings['cat_type']; ?>

                    <ul class="products-cat-list owl-carousel owl-theme <?php if ( 'yes' === $settings['dark_theme_active'] ) { ?> white <?php } ?>" id="<?php echo $settings['unique_widget_id']?>">
                        <?php
                            $args = array(
                                'post_type' => 'product',
                                'product_cat' => $post_by_woo_category,
                                'posts_per_page' => $number_of_posts
                                );
                            $loop = new \WP_Query( $args );
                            if ( $loop->have_posts() ) {
                                while ( $loop->have_posts() ) : $loop->the_post();?>
                                <div class="item">
                                    <div class="owl-content-slider">
                                        <?php  wc_get_template_part( 'content', 'product' ); ?>
                                    </div>
                                </div>
                               <?php endwhile;
                            } else {
                                echo __( 'No products found' );
                            }
                            wp_reset_postdata();
                        ?>
                    </ul><!--/.products-->

                <script>
                    jQuery( document ).ready( function( $ ) {
                        //Slider Post
                        $('#<?php echo $settings['unique_widget_id']?>').owlCarousel({
                            margin:20,
                            nav: false,
                            dots: true,
                            dotsContainer: '#wpsmart-<?php echo $settings['unique_widget_id']?>',
                            responsive:{
                                0:{items:<?php echo $settings['post_view_count_mobile']?>},
                                600:{items:<?php echo $settings['post_view_count_tablet']?>},
                                1000:{items:<?php echo $settings['post_view_count_desktop']?>}
                            }
                        });
                    } );
                </script>


            <?php } else {
                echo __( 'Please install Woocommerce Plugin' );
            } ?>


        </div>


        <?php
	}

	protected function _content_template() {}

    public function render_plain_content( $instance = [] ) {}
}
