<?php
/**
 * Plugin Name: Wpsmart Siren Wordpress Theme Blocks
 * Description: This is Add-on Plugin For "Wpsmart Siren Wordpress Theme" Widgets. You need to install This Plugin for Use Custom Theme Blocks
 * Plugin URI:  https://themeforest.net/user/wpsmart
 * Version:     1.5.5
 * Author:      Wpsmart
 * Author URI:  https://themeforest.net/user/wpsmart
 * Text Domain: wpsmart-elementor-plugin
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


final class WPSmart_newshub_plugin {


	const VERSION = '1.2.0';

	/**
	 * Minimum Elementor Version
	 *
	 * @since 1.2.0
	 * @var string Minimum Elementor version required to run the plugin.
	 */
	const MINIMUM_ELEMENTOR_VERSION = '2.0.0';

	/**
	 * Minimum PHP Version
	 *
	 * @since 1.2.0
	 * @var string Minimum PHP version required to run the plugin.
	 */
	const MINIMUM_PHP_VERSION = '5.4';

	/**
	 * Constructor
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function __construct() {

		// Load translation
		add_action( 'init', array( $this, 'i18n' ) );

		// Init Plugin
		add_action( 'plugins_loaded', array( $this, 'init' ) );
	}

	/**
	 * Load Textdomain
	 *
	 * Load plugin localization files.
	 * Fired by `init` action hook.
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function i18n() {
		load_plugin_textdomain( 'wpsmart-elementor-plugin' );
	}

	/**
	 * Initialize the plugin
	 *
	 * Validates that Elementor is already loaded.
	 * Checks for basic plugin requirements, if one check fail don't continue,
	 * if all check have passed include the plugin class.
	 *
	 * Fired by `plugins_loaded` action hook.
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function init() {

		// Check if Elementor installed and activated
		if ( ! did_action( 'elementor/loaded' ) ) {
			add_action( 'admin_notices', array( $this, 'admin_notice_missing_main_plugin' ) );
			return;
		}

		// Check for required Elementor version
		if ( ! version_compare( ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=' ) ) {
			add_action( 'admin_notices', array( $this, 'admin_notice_minimum_elementor_version' ) );
			return;
		}

		// Check for required PHP version
		if ( version_compare( PHP_VERSION, self::MINIMUM_PHP_VERSION, '<' ) ) {
			add_action( 'admin_notices', array( $this, 'admin_notice_minimum_php_version' ) );
			return;
		}

		// Once we get here, We have passed all validation checks so we can safely include our plugin
		require_once( 'plugin.php' );
	}

	/**
	 * Admin notice
	 *
	 * Warning when the site doesn't have Elementor installed or activated.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function admin_notice_missing_main_plugin() {
		if ( isset( $_GET['activate'] ) ) {
			unset( $_GET['activate'] );
		}

		$message = sprintf(
			/* translators: 1: Plugin name 2: Elementor */
			esc_html__( '"%1$s" requires "%2$s" to be installed and activated.', 'wpsmart-elementor-plugin' ),
			'<strong>' . esc_html__( 'Wpsmart Siren Wordpress Theme', 'wpsmart-elementor-plugin' ) . '</strong>',
			'<strong>' . esc_html__( 'Elementor', 'wpsmart-elementor-plugin' ) . '</strong>'
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
	}

	/**
	 * Admin notice
	 *
	 * Warning when the site doesn't have a minimum required Elementor version.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function admin_notice_minimum_elementor_version() {
		if ( isset( $_GET['activate'] ) ) {
			unset( $_GET['activate'] );
		}

		$message = sprintf(
			/* translators: 1: Plugin name 2: Elementor 3: Required Elementor version */
			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'wpsmart-elementor-plugin' ),
			'<strong>' . esc_html__( 'Wpsmart Siren Wordpress Theme', 'wpsmart-elementor-plugin' ) . '</strong>',
			'<strong>' . esc_html__( 'Elementor', 'wpsmart-elementor-plugin' ) . '</strong>',
			self::MINIMUM_ELEMENTOR_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
	}

	/**
	 * Admin notice
	 *
	 * Warning when the site doesn't have a minimum required PHP version.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function admin_notice_minimum_php_version() {
		if ( isset( $_GET['activate'] ) ) {
			unset( $_GET['activate'] );
		}

		$message = sprintf(
			/* translators: 1: Plugin name 2: PHP 3: Required PHP version */
			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'wpsmart-elementor-plugin' ),
			'<strong>' . esc_html__( 'Wpsmart Siren Wordpress Theme', 'wpsmart-elementor-plugin' ) . '</strong>',
			'<strong>' . esc_html__( 'PHP', 'wpsmart-elementor-plugin' ) . '</strong>',
			self::MINIMUM_PHP_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
	}
}


/**
 * Add Wpsmart Category
 *
 * Warning when the site doesn't have a minimum required PHP version.
 *
 * @since 1.0.0
 * @access public
 */

function header_and_footer_widget( $elements_manager ) {

    $elements_manager->add_category(
        'header_and_footer_widget',
        [
            'title' => __( 'Header And Footer Blocks', 'plugin-name' ),
            'icon' => 'fa fa-plug',
        ]
    );

}
add_action( 'elementor/elements/categories_registered', 'header_and_footer_widget' );

function add_elementor_widget_categories( $elements_manager ) {

    $elements_manager->add_category(
        'wpsmart-widget',
        [
            'title' => __( 'WPSmart Core Blocks', 'plugin-name' ),
            'icon' => 'fa fa-plug',
        ]
    );

}
add_action( 'elementor/elements/categories_registered', 'add_elementor_widget_categories' );

function post_type_widget( $elements_manager ) {

    $elements_manager->add_category(
        'wpsmart-post-widget',
        [
            'title' => __( 'WPSmart Post Blocks', 'plugin-name' ),
            'icon' => 'fa fa-plug',
        ]
    );

}
add_action( 'elementor/elements/categories_registered', 'post_type_widget' );

function archive_type( $elements_manager ) {

    $elements_manager->add_category(
        'wpsmart-archive-widget',
        [
            'title' => __( 'WPSmart Archive Blocks', 'plugin-name' ),
            'icon' => 'fa fa-plug',
        ]
    );

}
add_action( 'elementor/elements/categories_registered', 'archive_type' );

new WPSmart_newshub_plugin();
